********************************************************************************

********************************************************************************
**THIS DO-FILE CREATES FIGURES AND TABLES BASED ON THE FIRM PANEL DATASET
**Growing Markets through Business Training for Female Entrepreneurs: A Market-Level Randomized Experiment in Kenya
**November 20, 2017
**David McKenzie (dmckenzie@worldbank.org) and Susana Puerto
**The analysis was performed with Stata, version 14.2

*Note: Change the directory and paths to data used before running this do-file.

********************************************************************************

********************************************************************************

cd "/Users/Lu/Dropbox/AnnaLuisaProjects/KenyaDatatoAnonymize"

use "FullCombinedData.dta", clear

**** TABLE 1: INDIVIDUAL CHARACTERISTICS AND VERIFICATION OF RANDOMIZATION AT INDIVIDUAL LEVEL
gen b_married=cond(b_s1_18==2,1,0) if b_s1_18~=.
gen b_age=q5_years
replace b_age=. if b_age<14
gen b_numemployees=q12
replace b_numemployees=0 if b_numemployees==888
replace b_numemployees=. if b_numemployees==.|b_numemployees==999
gen b_keepsrecords=q13==2|q13==3
gen b_yearsedn=b_s1_16
replace b_yearsedn=b_s1_17 if b_s1_17~=.
replace b_s1_26c=. if b_s1_26c>20
replace b_s1_26b=. if b_s1_26b>20
gen b_hhsize=b_s1_26a+b_s1_26b+b_s1_26c
gen b_ageoffirm=2013-b_s1_10_year
replace b_ageoffirm=. if b_s1_10_year<1950|b_s1_10_year>2013
gen b_totalK=b_s5_1a_7
gen b_allK=b_totalK+b_inventories

*** Table: Verification of Randomization at the Individual Level

mat y = J(15,7,.)	
local j=1
foreach var of varlist b_age b_yearsedn b_married b_hhsize  b_ageoffirm b_numemployees censusprofits r1_salesweek b_allK b_receivedloan b_keepsrecords b_totalscore retail registered  {
sum `var' if r1_treated==1 & round==2
mat y[`j',1]=r(mean)
sum `var' if spillovertreat==1 & round==2
mat y[`j',2]=r(mean)
sum `var' if r1_treatedmarket==0 & round==2
mat y[`j',3]=r(mean)
mat y[`j',4]=r(sd)
areg `var' r1_treated if r1_treatedmarket==1 & round==2, a(r1_strata1) r
test r1_treated=0
mat y[`j',5]=r(p)
areg `var' r1_treated if spillovertreat==0 & round==2, a(r1_Strata) cluster(r1_market1)
test r1_treated=0
mat y[`j',6]=r(p)
areg `var' spillovertreat if r1_treated==0 & round==2, a(r1_Strata) cluster(r1_market1)
test spillovertreat=0
mat y[`j',7]=r(p)
local j=`j'+1
}
count if r1_treated==1 & round==2
mat y[15,1] = r(N)
count if spillovertreat==1 & round==2
mat y[15,2]= r(N)
count if r1_treatedmarket==0 & round==2
mat y[15,3]=r(N)
mat rownames y = "Age" "Years Educ" "Married" "HH Size" "Firm Age" "Employees" "Profits" "Sales" "Capital Stock" "Received Loan" "Keeps Records" "Management Score" "Retail" "Registered" "Sample Size"
mat colnames y = "Treatment" "Spillover" "Control" "SD" "p-value" "p-value" "p-value"
mat2txt, matrix(y) saving("output/Table1IndRandom.xls") replace

* Tests of joint orthogonality
areg r1_treated b_age b_yearsedn b_married b_hhsize  b_ageoffirm b_numemployees censusprofits r1_salesweek b_allK b_receivedloan b_keepsrecords b_totalscore retail registered if round==2 & r1_treatedmarket==1, a(r1_strata1)
areg r1_treated b_age b_yearsedn b_married b_hhsize  b_ageoffirm b_numemployees censusprofits r1_salesweek b_allK b_receivedloan b_keepsrecords b_totalscore retail registered if round==2 & spillovertreat==0, a(r1_Strata)
areg spillovertreat b_age b_yearsedn b_married b_hhsize  b_ageoffirm b_numemployees censusprofits r1_salesweek b_allK b_receivedloan b_keepsrecords b_totalscore retail registered if round==2 & r1_treated==0, a(r1_Strata)


**** TABLE 2: IMPACT ON PRIMARY OUTCOMES: SURVIVAL, PROFITS, AND SALES
est drop _all

* get baseline variables where applicable
foreach var of varlist r1_strata1 r1_salesday r1_salesday_miss r1_salesweek r1_salesweek_miss r1_salesmainprod r1_salesmainprod_miss r1_profitsweek r1_profmainprod r1_profmainprod_miss r1_profsalesindex r1_photoinventories r1_photo_miss r1_photoinv2 r1_photoinv2_miss r1_invsales r1_invprofits {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4|round==5
}

**** Convert nominal to real (august 2013) values
* Use Kenya National Bureau of Statistics CPIs for mid-round 
/*
August 2013: 140.29
August 2014: 152.02
January 2015: 153.43
April 2016: 167.07
July 2016: 170.84
*/
gen cpi=140.29/152.02 if round==2
replace cpi=140.29/153.43 if round==3
replace cpi=140.29/167.07 if round==4
replace cpi=140.29/170.84 if round==5

foreach var of varlist salesday salesweek salesmainprod profitsweek profmainprod photoinventories {
replace `var'=`var'*cpi
}



*** Testing impact in round 2/3 = impact in round 4/5
gen r23=round==2|round==3
gen r1_treated_r23=r1_treated*r23
gen spillovertreat_r23=spillovertreat*r23
gen r45=round==4|round==5
gen r1_treated_r45=r1_treated*r45
gen spillovertreat_r45=spillovertreat*r45
gen round4=round==4
replace round3=0 if round3==.
replace round5=0 if round5==.


***** Panel A: Direct and Spillover Effects of Training Assignment
eststo clear
* Survival
areg survives r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum survives if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_1
* Last Day Sales
areg salesday r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesday r1_salesday_miss round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesday if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_2
* Last Week Sales
areg salesweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesweek r1_salesweek_miss round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_3
* Main Product Sales
areg salesmainprod r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesmainprod r1_salesmainprod_miss round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesmainprod if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_4
* Weekly Profits
areg profitsweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profitsweek  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profitsweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_5
* Profits from main product
areg profmainprod r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profmainprod r1_profmainprod_miss  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profmainprod if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_6
* Photo inventories
areg photoinventories r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_photoinventories r1_photo_miss round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum photoinventories if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean=r(mean)
eststo table4_7
* Profits and Sales Index
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_8

#delimit ;
esttab table4_* using "output/table2panelA.csv", replace depvar legend label nonumbers
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 2: Impacts on Primary Outcomes - Panel A") addnotes("""") ;
#delimit cr


* version rounded to nearest integer
#delimit ;
esttab table4_* using "output/table2panelAa.csv", replace depvar legend label nonumbers
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2, fmt(%9.3f %9.0g %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2")) 
	title("Table 2: Impacts on Primary Outcomes - Panel A") addnotes("""") ;
#delimit cr

******** Panel B: Mentoring and Training
areg survives r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_1
*** Total sales in the last day
areg salesday r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesday r1_salesday_miss round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_2
*** Total sales in the last week
areg salesweek r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesweek r1_salesweek_miss round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_3
*** Total sales in the last week of product accounting for largest share of profits
areg salesmainprod r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesmainprod r1_salesmainprod_miss round5  if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_4
**** Profits
areg profitsweek r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profitsweek round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_5
**** Mark-up profits on main product
areg profmainprod r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profmainprod r1_profmainprod_miss  round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_6
**** Photo-valued inventories
areg photoinventories r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill if round==4, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_7
**** Profit and Sales Index
areg profsalesindex r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profsalesindex round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_8

#delimit ;
esttab table4b_* using "output/table2panelB.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(N pval, fmt(%9.0g %9.3f) labels( "Sample Size" "P-value")) 
	title("Table 2: Impacts on Primary outcomes - Panel B") addnotes("""") ;
#delimit cr

#delimit ;
esttab table4b_* using "output/table2panelBa.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(N pval, fmt( %9.0g %9.3f) labels( "Sample Size" "P-value")) 
	title("Table 2: Impacts on Primary outcomes - Panel B") addnotes("""") ;
#delimit cr


**** TABLE 3: IMPACT ON SECONDARY OUTCOMES
foreach var of varlist  b_empowerment b_empower_miss b_assetindex {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4
}

eststo clear
* B1: Employed for Pay
areg employedforpay r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum employedforpay if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_1
* B1: Income from work
areg incomefromwork r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum incomefromwork if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_2
* B2: Empowerment
areg empowerment r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 b_empowerment b_empower_miss round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum empowerment if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table4_3
* B3: Subjective Well-being
areg laddertoday r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4  round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum laddertoday if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_4
areg ladder5years r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4  round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum ladder5years if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_5
areg mhi5 r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum mhi5 if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table4_6
areg assetindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 b_assetindex round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum assetindex if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table4_7

#delimit ;
esttab table4_* using "output/table3panelA.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 3: Impacts on Secondary Outcomes - Panel A") addnotes("""") ;
#delimit cr


*** Panel B: Separating mentoring effect
eststo clear
* B1: Employed for Pay
areg employedforpay r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum employedforpay if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_1
* B1: Income from work
areg incomefromwork r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum incomefromwork if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_2
* B2: Empowerment
areg empowerment r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum empowerment if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_3
* B3: Subjective Well-being
areg laddertoday r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum laddertoday if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_4
areg ladder5years r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill round5 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum ladder5years if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_5
areg mhi5 r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum mhi5 if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_6
areg assetindex r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum assetindex if r1_treatedmarket==0 & e(sample) & round==2 & msmallmkt==0
estadd scalar mean = r(mean)
eststo tableBM_7

#delimit ;
esttab tableBM_* using "output/table3panelB.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval, fmt(%9.3f %9.0g %9.3f) labels("Mean of Pure Control Group" "Sample Size")) 
	title("Table 3: Impacts on Secondary Outcomes - Panel B") addnotes("""") ;
#delimit cr


**** TABLE 4: IMPACTS ON MARKET LEVEL FOR WOMEN
egen marketcust=mean(numcustomers), by(r1_market1 round)
egen marketindex=mean(profsalesindex), by(r1_market1 round)
egen r1_marketindex=mean(r1_profsalesindex), by(r1_market1)
egen r1_marketprof=mean(r1_profitsweek), by(r1_market1)
egen r1_marketsales=mean(r1_salesweek), by(r1_market1)
gen r1_treatedmarket_r23=r1_treatedmarket*r23
gen r1_treatedmarket_r45=r1_treatedmarket*r45

egen totalprof=sum(profitsweek), by(r1_market1 round)
egen r1_totalprof=sum(r1_profitsweek), by(r1_market1)
egen totalsales=sum(salesweek), by(r1_market1 round)
egen r1_totalsales=sum(r1_salesweek), by(r1_market1)
egen totalcust=sum(numcustomers), by(r1_market1 round)

eststo clear
preserve
gen marketround=r1_market1+10000*round
duplicates drop marketround, force

* Training vs Control - All Markets
areg totalprof r1_treatedmarket_r23 r1_treatedmarket_r45 round3 round4 round5 r1_totalprof, a(r1_Strata)  cluster(r1_market1)
test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum totalprof if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean = r(mean)
eststo table5_1
areg totalsales r1_treatedmarket_r23 r1_treatedmarket_r45 round3 round4 round5 r1_totalsales, a(r1_Strata)  cluster(r1_market1)
test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum totalsales if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean = r(mean)
eststo table5_2
areg totalcust r1_treatedmarket_r23 r1_treatedmarket_r45 round3 round4 round5, a(r1_Strata)  cluster(r1_market1)
test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum totalcust if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean = r(mean)
eststo table5_3


#delimit ;
esttab table5_* using "output/table4A.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval, fmt(%9.2f %9.0f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval")) 
	title("Table 4: Impacts on Market Level - All Markets") addnotes("""") ;
#delimit cr

restore

#delimit ;
esttab table5_* using "output/table4Aa.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval, fmt(%9.0f %9.0f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval")) 
	title("Table 4: Impacts on Market Level - All Markets") addnotes("""") ;
#delimit cr


***** New entrants
eststo clear
preserve
keep if round==2|round==4
gen marketround=r1_market1+10000*round
duplicates drop marketround, force
sort r1_market1 round
cap drop _merge
merge r1_market1 round using "Round3NewEntrants.dta"
keep if _merge==3
drop _merge
areg newentrants r1_treatedmarket_r23 r1_treatedmarket_r45 round4, a(r1_Strata)  cluster(r1_market1)
test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum newentrants if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean = r(mean)
eststo table5_1
areg otherfirms r1_treatedmarket_r23 r1_treatedmarket_r45 round4, a(r1_Strata) cluster(r1_market1)
test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum otherfirms if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean = r(mean)
eststo table5_2
 areg profother r1_treatedmarket_r23 r1_treatedmarket_r45 round4, a(r1_Strata) cluster(r1_market1)
 test r1_treatedmarket_r23==r1_treatedmarket_r45
estadd scalar pval=r(p)
sum profother if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean = r(mean)
eststo table5_3

 #delimit ;
esttab table5_* using "output/table4B.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval, fmt(%9.2f %9.0f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval")) 
	title("Table 4: Impacts on Market Level - New Entrants") addnotes("""") ;
#delimit cr

 
restore


***** TABLE 5: MARKET LEVEL IMPACTS IN 2017 INCLUDING MALES
use Female&MaleVendorSurveys_combined, clear

gen maleowner=q3_gender==1
gen maleindirect=maleowner==1 & mtreatedmarket==1
replace malesector=0 if malesector==.
gen male_studysector=maleindirect==1 & malesector==0
gen male_othersector=maleindirect==1 & malesector==1

replace r1_treated=0 if r1_treated==.
replace spillovertreat=0 if spillovertreat==.
replace r1_mentored=0 if r1_mentored==.
replace r1_trainonly=0 if r1_trainonly==.
replace r1_mentor_spill=0 if r1_mentor_spill==.
replace r1_trainonly_spill=0 if r1_trainonly_spill==0

areg logsales r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill if msmallmkt==0 & _merge==3, a(mStrata) cluster(marketid)
test r1_mentored==r1_trainonly
areg logprof r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill if msmallmkt==0 & _merge==3, a(mStrata) cluster(marketid)
test r1_mentored==r1_trainonly

eststo clear
* Does treatment status affect whether we interview women in the market?
areg intoperate r1_treated spillovertreat if _merge==3, a(r1_Strata) cluster(r1_market1)
sum intoperate if mtreatedmarket==0 & e(sample) 
estadd scalar mean = r(mean)
eststo table5_1

* Impact on Log Sales of Firms Currently Operating
areg logsales r1_treated spillovertreat maleindirect maleowner, a(mStrata) cluster(marketid)
sum logsales if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_2

* Impact on Log Sales of Firms Currently Operating by Male Sector
areg logsales r1_treated spillovertreat male_studysector male_othersector maleowner, a(mStrata) cluster(marketid)
sum logsales if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_3


* Impact on Average Sales in the Market
areg logsales mtreatedmarket maleowner, a(mStrata) cluster(marketid)
sum logsales if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_4

* Impact on Log Profits of Firms Currently Operating
areg logprof r1_treated spillovertreat maleindirect maleowner, a(mStrata) cluster(marketid)
sum logprof if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_5

* Impact on Log Profits of Firms Currently Operating by Male Sector
areg logprof r1_treated spillovertreat male_studysector male_othersector maleowner, a(mStrata) cluster(marketid)
sum logprof if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_6

* Impact on Average Profits in the Market
areg logprof mtreatedmarket maleowner, a(mStrata) cluster(marketid)
sum logprof if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table5_7

#delimit ;
esttab table5_* using "output/table5.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N, fmt(%9.3f %9.0g) labels("Mean of Female Pure Control Group" "Sample Size")) 
	title("Table 5: Market Level Impacts in 2017 including males") addnotes("""") ;
#delimit cr


***** TABLE 6: IMPACTS ON BUSINESS KNOWLEDGE, BUSINESS PRACTICES, AND MENTOR USAGE 
use "FullCombinedData.dta", clear

gen b_married=cond(b_s1_18==2,1,0) if b_s1_18~=.
gen b_age=q5_years
replace b_age=. if b_age<14
gen b_numemployees=q12
replace b_numemployees=0 if b_numemployees==888
replace b_numemployees=. if b_numemployees==.|b_numemployees==999
gen b_keepsrecords=q13==2|q13==3
gen b_yearsedn=b_s1_16
replace b_yearsedn=b_s1_17 if b_s1_17~=.
replace b_s1_26c=. if b_s1_26c>20
replace b_s1_26b=. if b_s1_26b>20
gen b_hhsize=b_s1_26a+b_s1_26b+b_s1_26c
gen b_ageoffirm=2013-b_s1_10_year
replace b_ageoffirm=. if b_s1_10_year<1950|b_s1_10_year>2013
gen b_totalK=b_s5_1a_7
gen b_allK=b_totalK+b_inventories



* get baseline variables where applicable
foreach var of varlist r1_strata1 r1_salesday r1_salesday_miss r1_salesweek r1_salesweek_miss r1_salesmainprod r1_salesmainprod_miss r1_profitsweek r1_profmainprod r1_profmainprod_miss r1_profsalesindex r1_photoinventories r1_photo_miss r1_photoinv2 r1_photoinv2_miss r1_invsales r1_invprofits {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4|round==5
}

**** Convert nominal to real (august 2013) values
* Use Kenya National Bureau of Statistics CPIs for mid-round 
/*
August 2013: 140.29
August 2014: 152.02
January 2015: 153.43
April 2016: 167.07
July 2016: 170.84
*/
gen cpi=140.29/152.02 if round==2
replace cpi=140.29/153.43 if round==3
replace cpi=140.29/167.07 if round==4
replace cpi=140.29/170.84 if round==5

foreach var of varlist salesday salesweek salesmainprod profitsweek profmainprod photoinventories {
replace `var'=`var'*cpi
}



*** Testing impact in round 2/3 = impact in round 4/5
gen r23=round==2|round==3
gen r1_treated_r23=r1_treated*r23
gen spillovertreat_r23=spillovertreat*r23
gen r45=round==4|round==5
gen r1_treated_r45=r1_treated*r45
gen spillovertreat_r45=spillovertreat*r45
gen round4=round==4
replace round3=0 if round3==.
replace round5=0 if round5==.

foreach var of varlist  b_empowerment b_empower_miss b_assetindex {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4
}

egen marketcust=mean(numcustomers), by(r1_market1 round)
egen marketindex=mean(profsalesindex), by(r1_market1 round)
egen r1_marketindex=mean(r1_profsalesindex), by(r1_market1)
egen r1_marketprof=mean(r1_profitsweek), by(r1_market1)
egen r1_marketsales=mean(r1_salesweek), by(r1_market1)
gen r1_treatedmarket_r23=r1_treatedmarket*r23
gen r1_treatedmarket_r45=r1_treatedmarket*r45

egen totalprof=sum(profitsweek), by(r1_market1 round)
egen r1_totalprof=sum(r1_profitsweek), by(r1_market1)
egen totalsales=sum(salesweek), by(r1_market1 round)
egen r1_totalsales=sum(r1_salesweek), by(r1_market1)
egen totalcust=sum(numcustomers), by(r1_market1 round)

egen mb_totalscore=max(b_totalscore), by(respid)
replace b_totalscore=mb_totalscore if round==4
egen mb_totalscore_miss=max(b_totalscore_miss), by(respid)
replace b_totalscore_miss=mb_totalscore_miss if round==4

#delimit ;
foreach var of varlist b_monitorrecs b_monitorrecs_miss b_monitorrecs b_monitorrecs_miss b_receivedloan b_receivedloan_miss 
b_inventories b_inventories_miss b_ownedcapital b_ownedcapital_miss b_laborhours b_laborhours_miss b_belongmerrygo {;
cap drop m`var';
egen m`var'=max(`var'), by(respid);
replace `var'=m`var' if round==4 ;
};
#delimit cr



eststo clear
*** Hypothesis D1: business knowledge and business practices (and mentoring )
areg knowledge r1_treated spillovertreat if round==2, cluster(r1_market1) a(r1_Strata)
sum knowledge if r1_treatedmarket==0 & e(sample)
estadd scalar mean = r(mean)
eststo table5_1

areg totalscore r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 b_totalscore b_totalscore_miss round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum totalscore if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table5_2

areg workedmentor r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum workedmentor if r1_treatedmarket==0 & e(sample)
estadd scalar mean = r(mean)
eststo table5_3

* with mentoring effect separated
areg totalscore r1_mentored r1_trainonly r1_mentor_spill r1_trainonly_spill b_totalscore b_totalscore_miss if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table5_5

areg workedmentor r1_mentored r1_trainonly r1_mentor_spill r1_trainonly_spill if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table5_6

#delimit ;
esttab table5_* using "output/table6.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 6: Impacts on Business Knowledge, Practices, and Mentoring") addnotes("""") ;
#delimit cr


**** TABLE 7: IMPACT ON DEALING WITH CUSTOMERS

* generate weekly sales per customer
gen salespercustomer=salesweek/numcustomers

* put zeros in for new products for closed firms
gen introduce_uncon=introducenew
replace introduce_uncon=0 if survives==0

*** Hypothesis D2: customers 
eststo clear
areg numcustomers r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum numcustomers if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table6_1

areg gainednewcus r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum gainednewcus if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table6_2

areg lostcust r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum lostcust if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table6_3

areg salespercust r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salespercust if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table6_4

areg openatfixedtime  r1_treated_r45  spillovertreat_r45  if round==4, cluster(r1_market1) a(r1_Strata)
sum openatfixedtime if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table6_5

areg introduce_uncon r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum introduce_uncon if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table6_6

* Panel B: With mentoring
areg numcustomers r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  round4 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_7

areg gainednewcus r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  round4 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_8

areg lostcust r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  round4 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_9

areg salespercust r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  round4 if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_10

areg openatfixedtime  r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_11

areg introduce_uncon r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  if (round==4) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1=r(p)
eststo table6_12

#delimit ;
esttab table6_* using "output/table7.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 7: Impact on Dealings with Customers") addnotes("""") ;
#delimit cr

#delimit ;
esttab table6_* using "output/table7a.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.1f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 7: Impact on Dealings with Customers") addnotes("""") ;
#delimit cr


***** TABLE 8: MULTIPLIER EFFECTS - IMPACT ON PERCENT OF CUSTOMERS THAT ARE OTHER BUSINESSES
use Female&MaleVendorSurveys_combined, clear

gen maleowner=q3_gender==1
gen maleindirect=maleowner==1 & mtreatedmarket==1
replace malesector=0 if malesector==.
gen male_studysector=maleindirect==1 & malesector==0
gen male_othersector=maleindirect==1 & malesector==1

replace r1_treated=0 if r1_treated==.
replace spillovertreat=0 if spillovertreat==.
replace r1_mentored=0 if r1_mentored==.
replace r1_trainonly=0 if r1_trainonly==.
replace r1_mentor_spill=0 if r1_mentor_spill==.
replace r1_trainonly_spill=0 if r1_trainonly_spill==0

* discretize share
gen discreteshare=5 if q9_custoshare==1
replace discreteshare=17.5 if q9_custoshare==2
replace discreteshare=37.5 if q9_custoshare==3
replace discreteshare=62.5 if q9_custoshare==4
replace discreteshare=87.5 if q9_custoshare==5

eststo clear
areg q9_custoshare r1_treated spillovertreat male_studysector male_othersector maleowner, a(mStrata) cluster(marketid)
sum q9_custoshare if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table6_1

areg discreteshare r1_treated spillovertreat male_studysector male_othersector maleowner, a(mStrata) cluster(marketid)
sum discreteshare if mtreatedmarket==0 & maleowner==0
estadd scalar mean = r(mean)
eststo table6_2

#delimit ;
esttab table6_* using "output/table8.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N, fmt(%9.3f %9.0g) labels("Mean of Female Pure Control Group" "Sample Size")) 
	title("Table 8: Multiplier Effects - Impact on Percent of Customers that are other businesses ") addnotes("""") ;
#delimit cr


***** TABLE 9: IMPACTS ON FINANCIAL CONTROL, ACCESS TO FINANCE, AND CAPITAL LEVELS
use "FullCombinedData.dta", clear

gen b_married=cond(b_s1_18==2,1,0) if b_s1_18~=.
gen b_age=q5_years
replace b_age=. if b_age<14
gen b_numemployees=q12
replace b_numemployees=0 if b_numemployees==888
replace b_numemployees=. if b_numemployees==.|b_numemployees==999
gen b_keepsrecords=q13==2|q13==3
gen b_yearsedn=b_s1_16
replace b_yearsedn=b_s1_17 if b_s1_17~=.
replace b_s1_26c=. if b_s1_26c>20
replace b_s1_26b=. if b_s1_26b>20
gen b_hhsize=b_s1_26a+b_s1_26b+b_s1_26c
gen b_ageoffirm=2013-b_s1_10_year
replace b_ageoffirm=. if b_s1_10_year<1950|b_s1_10_year>2013
gen b_totalK=b_s5_1a_7
gen b_allK=b_totalK+b_inventories



* get baseline variables where applicable
foreach var of varlist r1_strata1 r1_salesday r1_salesday_miss r1_salesweek r1_salesweek_miss r1_salesmainprod r1_salesmainprod_miss r1_profitsweek r1_profmainprod r1_profmainprod_miss r1_profsalesindex r1_photoinventories r1_photo_miss r1_photoinv2 r1_photoinv2_miss r1_invsales r1_invprofits {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4|round==5
}

**** Convert nominal to real (august 2013) values
* Use Kenya National Bureau of Statistics CPIs for mid-round 
/*
August 2013: 140.29
August 2014: 152.02
January 2015: 153.43
April 2016: 167.07
July 2016: 170.84
*/
gen cpi=140.29/152.02 if round==2
replace cpi=140.29/153.43 if round==3
replace cpi=140.29/167.07 if round==4
replace cpi=140.29/170.84 if round==5

foreach var of varlist salesday salesweek salesmainprod profitsweek profmainprod photoinventories {
replace `var'=`var'*cpi
}



*** Testing impact in round 2/3 = impact in round 4/5
gen r23=round==2|round==3
gen r1_treated_r23=r1_treated*r23
gen spillovertreat_r23=spillovertreat*r23
gen r45=round==4|round==5
gen r1_treated_r45=r1_treated*r45
gen spillovertreat_r45=spillovertreat*r45
gen round4=round==4
replace round3=0 if round3==.
replace round5=0 if round5==.

foreach var of varlist  b_empowerment b_empower_miss b_assetindex {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if round==4
}

egen marketcust=mean(numcustomers), by(r1_market1 round)
egen marketindex=mean(profsalesindex), by(r1_market1 round)
egen r1_marketindex=mean(r1_profsalesindex), by(r1_market1)
egen r1_marketprof=mean(r1_profitsweek), by(r1_market1)
egen r1_marketsales=mean(r1_salesweek), by(r1_market1)
gen r1_treatedmarket_r23=r1_treatedmarket*r23
gen r1_treatedmarket_r45=r1_treatedmarket*r45

egen totalprof=sum(profitsweek), by(r1_market1 round)
egen r1_totalprof=sum(r1_profitsweek), by(r1_market1)
egen totalsales=sum(salesweek), by(r1_market1 round)
egen r1_totalsales=sum(r1_salesweek), by(r1_market1)
egen totalcust=sum(numcustomers), by(r1_market1 round)

egen mb_totalscore=max(b_totalscore), by(respid)
replace b_totalscore=mb_totalscore if round==4
egen mb_totalscore_miss=max(b_totalscore_miss), by(respid)
replace b_totalscore_miss=mb_totalscore_miss if round==4

#delimit ;
foreach var of varlist b_monitorrecs b_monitorrecs_miss b_monitorrecs b_monitorrecs_miss b_receivedloan b_receivedloan_miss 
b_inventories b_inventories_miss b_ownedcapital b_ownedcapital_miss b_laborhours b_laborhours_miss b_belongmerrygo {;
cap drop m`var';
egen m`var'=max(`var'), by(respid);
replace `var'=m`var' if round==4 ;
};
#delimit cr

replace inventories=inventories*cpi
replace ownedcapital=ownedcapital*cpi

*** Hypothesis D3: sales in downtimes
eststo clear
areg ratioprof r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum ratioprof if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table7_1

areg monitorrecs r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum monitorrecs if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_2

*** Hypothesis D5: stock losses, and buying 
areg fractionstocklost r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum fractionstocklost if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_3

areg bulkdiscount r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum bulkdiscount if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_4

areg prodcostchange r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum prodcostchange if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_5

*** Hypothesis D4: financing, inventories, and capital
areg receivedloan r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum receivedloan if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_6

areg businessbank  r1_treated_r45  spillovertreat_r45 if round==4, cluster(r1_market1) a(r1_Strata)
sum businessbank if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_7

areg inventories r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum inventories if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_8

areg ownedcapital r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 b_ownedcapital b_ownedcapital_miss if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum ownedcapital if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table7_9

#delimit ;
esttab table7_* using "output/table9panelA.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 9: Impacts on Financial Control, Access to Finance, and Capital Levels - Panel A") addnotes("""") ;
#delimit cr


*** Panel B: With Mentoring
*** Hypothesis D3: sales in downtimes
eststo clear
areg ratioprof r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_1

areg monitorrecs r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_2

*** Hypothesis D5: stock losses, and buying 
areg fractionstocklost r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_3

areg bulkdiscount r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_4

areg prodcostchange r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_5

*** Hypothesis D4: financing, inventories, and capital
areg receivedloan r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_6

areg businessbank  r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_7

areg inventories r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill   if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_8

areg ownedcapital r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill b_ownedcapital b_ownedcapital_miss  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table7b_9

#delimit ;
esttab table7b_* using "output/table9panelB.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 9: Impacts on Financial Control, Access to Finance, and Capital Levels - Panel B") addnotes("""") ;
#delimit cr

#delimit ;
esttab table7b_* using "output/table9panelBa.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.0f %9.0f %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 9: Impacts on Financial Control, Access to Finance, and Capital Levels - Panel B") addnotes("""") ;
#delimit cr



***** TABLE 10: ATTITUDES AND ASSOCIATIONS

*** Hypothesis D6: self-efficacy (not asked r4), work hours and attitudes (not asked r4)
eststo clear
areg laborhours r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 b_laborhours b_laborhours_miss round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum laborhours if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table8_1

areg selfefficacy r1_treated_r23  spillovertreat_r23  if (round==2), cluster(r1_market1) a(r1_Strata)
sum selfefficacy if r1_treatedmarket==0 & e(sample)
estadd scalar mean = r(mean)
eststo table8_2

areg GETattitude r1_treated_r23  spillovertreat_r23 b_GETattitude b_GETattitude_miss if (round==2), cluster(r1_market1) a(r1_Strata)
sum GETattitude if r1_treatedmarket==0 & e(sample)
estadd scalar mean = r(mean)
eststo table8_3


*** Hypothesis D7: Social capital and connections 
areg belongwomenassoc r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum belongwomenassoc if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table8_4

areg discussbusiness r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum discussbusiness if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table8_5

areg worktogether r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round4 if (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum worktogether if r1_treatedmarket==0 & e(sample) & (round==4)
estadd scalar mean=r(mean)
eststo table8_6

#delimit ;
esttab table8_* using "output/table10panelA.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 10: Attitudes and Associations - Panel A") addnotes("""") ;
#delimit cr

**** Panel B: with mentoring
eststo clear
areg laborhours r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill b_laborhours b_laborhours_miss  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table8b_1

*** Hypothesis D7: Social capital and connections 
areg belongwomenassoc r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table8b_4

areg discussbusiness r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table8b_5

areg worktogether r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval1= r(p)
eststo table8b_6


#delimit ;
esttab table8b_* using "output/table10panelB.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Table 10: Attitudes and Associations - Panel B") addnotes("""") ;
#delimit cr


**** FIGURE 2:QUANTILE TREATMENT EFFECTS ON PROFITS AFTER THREE YEARS

xi: qreg2 profitsweek r1_treated_r45 spillovertreat_r45 r1_profitsweek round4 i.r1_Strata if (round==4|round==5), cluster(r1_market1) 

clear matrix
 	preserve
	
	forval i=.05(.05).95 {
		di `i'
		
		*OLS regression:
quietly areg profitsweek r1_treated_r45 spillovertreat_r45 r1_profitsweek round4  if (round==4|round==5), cluster(r1_market1) a(r1_Strata)		 
		scalar betaols=_b[r1_treated_r45]

		*Quantile regression:
quietly xi: qreg2 profitsweek r1_treated_r45 spillovertreat_r45 r1_profitsweek round4 i.r1_Strata if (round==4|round==5), cluster(r1_market1) q(`i')
		scalar beta = _b[r1_treated_r45]
		scalar sigma = _se[r1_treated_r45]
		
		scalar cil = beta - (1.96*sigma)
		scalar ciu = beta + (1.96*sigma)
		matrix round4_qreg = [nullmat(round4_qreg) \ `i', betaols, beta, cil, ciu]
		}

	clear
	svmat round4_qreg
	ren round4_qreg1 qtile
	ren round4_qreg2 ols_treatment
	ren round4_qreg3 treatment
	ren round4_qreg4 treatment_cilo
	ren round4_qreg5 treatment_cihi
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
format treatment ols_treatment treatment_cihi treatment_cilo %6.0f 

label var treatment "Quantile treatment effect"
label var ols_treatment "OLS"
la var treatment_cihi "95% C.I"

twoway (line ols_treatment Percentile, lpattern(dash)) ///
	   (line treatment Percentile, lwidth(medthick) lcolor(gray lpattern(line))) ///
	   (line y0 Percentile, lcolor(black)) ///
	   (line treatment_cihi Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)) ///
	   (line treatment_cilo Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)), ///
	    xlabel(5 10 20 30 40 50 60 70 80 90 95) ///
		title(Treatment Effect) ytitle("Weekly Profits") ///
		scheme(s1manual) legend(off) legend(rows(1))
graph save "output/FigureQ1.gph", replace
restore

*** Quantile Effects of Spillover
clear matrix
 	preserve
	
	forval i=.05(.05).95 {
		di `i'
		
		*OLS regression:
quietly areg profitsweek r1_treated_r45 spillovertreat_r45 r1_profitsweek round4  if (round==4|round==5), cluster(r1_market1) a(r1_Strata)		 
		scalar betaols=_b[spillovertreat_r45]

		*Quantile regression:
quietly xi: qreg2 profitsweek r1_treated_r45 spillovertreat_r45 r1_profitsweek round4 i.r1_Strata if (round==4|round==5), cluster(r1_market1) q(`i')
		scalar beta = _b[spillovertreat_r45]
		scalar sigma = _se[spillovertreat_r45]
		
		scalar cil = beta - (1.96*sigma)
		scalar ciu = beta + (1.96*sigma)
		matrix round4_qreg = [nullmat(round4_qreg) \ `i', betaols, beta, cil, ciu]
		}

	clear
	svmat round4_qreg
	ren round4_qreg1 qtile
	ren round4_qreg2 ols_treatment
	ren round4_qreg3 treatment
	ren round4_qreg4 treatment_cilo
	ren round4_qreg5 treatment_cihi
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
format treatment ols_treatment treatment_cihi treatment_cilo %6.0f 

label var treatment "Quantile treatment effect"
label var ols_treatment "OLS"
la var treatment_cihi "95% C.I"

twoway (line ols_treatment Percentile, lpattern(dash)) ///
	   (line treatment Percentile, lwidth(medthick) lcolor(gray lpattern(line))) ///
	   (line y0 Percentile, lcolor(black)) ///
	   (line treatment_cihi Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)) ///
	   (line treatment_cilo Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)), ///
	    xlabel(5 10 20 30 40 50 60 70 80 90 95) ///
		title(Spillover effect) ytitle("Weekly Profits") ///
		scheme(s1manual) legend(off) legend(rows(1))
graph save "output/FigureQ1s.gph", replace
restore 

graph combine "output/FigureQ1.gph" "output/FigureQ1s.gph", col(2) ycommon graphregion(fcolor(white))
graph save "output/Figure2QuantileTreatmentEffects_Profits.gph", replace
erase "output/FigureQ1.gph"
erase "output/FigureQ1s.gph"

**** FIGURE 3:QUANTILE TREATMENT EFFECTS ON SALES AFTER THREE YEARS

clear matrix
 	preserve
	
	forval i=.05(.05).95 {
		di `i'
		
		*OLS regression:
quietly areg salesweek r1_treated_r45 spillovertreat_r45 r1_salesweek r1_salesweek_miss round4  if (round==4|round==5), cluster(r1_market1) a(r1_Strata)		 
		scalar betaols=_b[r1_treated_r45]

		*Quantile regression:
quietly xi: qreg2 salesweek r1_treated_r45 spillovertreat_r45 r1_salesweek r1_salesweek_miss round4 i.r1_Strata if (round==4|round==5), cluster(r1_market1) q(`i')
		scalar beta = _b[r1_treated_r45]
		scalar sigma = _se[r1_treated_r45]
		
		scalar cil = beta - (1.96*sigma)
		scalar ciu = beta + (1.96*sigma)
		matrix round4_qreg = [nullmat(round4_qreg) \ `i', betaols, beta, cil, ciu]
		}

	clear
	svmat round4_qreg
	ren round4_qreg1 qtile
	ren round4_qreg2 ols_treatment
	ren round4_qreg3 treatment
	ren round4_qreg4 treatment_cilo
	ren round4_qreg5 treatment_cihi
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
format treatment ols_treatment treatment_cihi treatment_cilo %6.0f 

label var treatment "Quantile treatment effect"
label var ols_treatment "OLS"
la var treatment_cihi "95% C.I"

twoway (line ols_treatment Percentile, lpattern(dash)) ///
	   (line treatment Percentile, lwidth(medthick) lcolor(gray lpattern(line))) ///
	   (line y0 Percentile, lcolor(black)) ///
	   (line treatment_cihi Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)) ///
	   (line treatment_cilo Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)), ///
	    xlabel(5 10 20 30 40 50 60 70 80 90 95) ///
		title(Treatment Effect) ytitle("Weekly Sales") ///
		scheme(s1manual) legend(order(1 2 4)) legend(off)
graph save "output/FigureQ2.gph", replace
restore

*** Quantile Effects of Spillover
clear matrix
 	preserve
	
	forval i=.05(.05).95 {
		di `i'
		
		*OLS regression:
quietly areg salesweek r1_treated_r45 spillovertreat_r45 r1_salesweek r1_salesweek_miss round4  if (round==4|round==5), cluster(r1_market1) a(r1_Strata)		 
		scalar betaols=_b[spillovertreat_r45]

		*Quantile regression:
quietly xi: qreg2 salesweek r1_treated_r45 spillovertreat_r45 r1_salesweek r1_salesweek_miss round4 i.r1_Strata if (round==4|round==5), cluster(r1_market1) q(`i')
		scalar beta = _b[spillovertreat_r45]
		scalar sigma = _se[spillovertreat_r45]
		
		scalar cil = beta - (1.96*sigma)
		scalar ciu = beta + (1.96*sigma)
		matrix round4_qreg = [nullmat(round4_qreg) \ `i', betaols, beta, cil, ciu]
		}

	clear
	svmat round4_qreg
	ren round4_qreg1 qtile
	ren round4_qreg2 ols_treatment
	ren round4_qreg3 treatment
	ren round4_qreg4 treatment_cilo
	ren round4_qreg5 treatment_cihi
	
gen y0=0
gen Percentile=qtile*100
sort Percentile
replace y0=. if Percentile<5 | Percentile>95
format treatment ols_treatment treatment_cihi treatment_cilo %6.0f 

label var treatment "Quantile treatment effect"
label var ols_treatment "OLS"
la var treatment_cihi "95% C.I"

twoway (line ols_treatment Percentile, lpattern(dash)) ///
	   (line treatment Percentile, lwidth(medthick) lcolor(gray lpattern(line))) ///
	   (line y0 Percentile, lcolor(black)) ///
	   (line treatment_cihi Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)) ///
	   (line treatment_cilo Percentile, lwidth(thin) lpattern(longdash_dot_dot) lcolor(navy)), ///
	    xlabel(5 10 20 30 40 50 60 70 80 90 95) ///
		title(Spillover Effect) ytitle("Weekly Sales") ///
		scheme(s1manual) legend(order(1 2 4)) legend(off)
graph save "output/FigureQ2s.gph", replace
restore 

graph combine "output/FigureQ2.gph" "output/FigureQ2s.gph", col(2) ycommon graphregion(fcolor(white))
graph save "output/Figure3QuantileTreatmentEffects_Sales.gph", replace
erase "output/FigureQ2.gph"
erase "output/FigureQ2s.gph"


**** APPENDIX 4: SAMPLE MEANS BY ASSIGNMENT TO MENTORING OR TRAINING ONLY
* APPENDIX TABLE 2: MEANS BY TREATMENT STATUS FOR MENTORING INTERVENTION
mat y = J(15,7,.)	
local j=1
foreach var of varlist b_age b_yearsedn b_married b_hhsize  b_ageoffirm b_numemployees censusprofits r1_salesweek b_allK b_receivedloan b_keepsrecords b_totalscore retail registered  {
sum `var' if r1_mentored==1 & round==2 & msmallmkt==0
mat y[`j',1]=r(mean)
sum `var' if r1_trainonly==1 & round==2 & msmallmkt==0
mat y[`j',2]=r(mean)
sum `var' if r1_mentor_spill==1 & round==2 & msmallmkt==0
mat y[`j',3]=r(mean)
sum `var' if r1_trainonly_spill==1 & round==2 & msmallmkt==0
mat y[`j',4]=r(mean)
sum `var' if r1_treatedmarket==0 & round==2 & msmallmkt==0
mat y[`j',5]=r(mean)
areg `var' r1_mentored if (r1_mentored==1|r1_trainonly==1) & round==2 & msmallmkt==0, a(r1_Strata) cluster(r1_market1)
test r1_mentored=0
mat y[`j',6]=r(p)
areg `var' r1_mentor_spill if (r1_mentor_spill==1|r1_trainonly_spill==1) & round==2 & msmallmkt==0, a(r1_Strata) cluster(r1_market1)
test r1_mentor_spill=0
mat y[`j',7]=r(p)
local j=`j'+1
}
count if r1_mentored==1 & round==2 & msmallmkt==0
mat y[15,1] = r(N)
count if r1_trainonly==1 & round==2 & msmallmkt==0
mat y[15,2]= r(N)
count if r1_mentor_spill==1 & round==2 & msmallmkt==0
mat y[15,3]=r(N)
count if r1_trainonly_spill==1 & round==2 & msmallmkt==0
mat y[15,4]=r(N)
count if r1_treatedmarket==0 & round==2 & msmallmkt==0
mat y[15,5]=r(N)

mat rownames y = "Age" "Years Educ" "Married" "HH Size" "Firm Age" "Employees" "Profits" "Sales" "Capital Stock" "Received Loan" "Keeps Records" "Management Score" "Retail" "Registered" "Sample Size"
mat colnames y = "Mentor" "Train Only" "Spillover Mentor" "Spillover Train" "Control"  "p-value" "p-value"
mat2txt, matrix(y) saving("output/Appendix4Table1IndRandom.xls") replace


**** APPENDIX 7: DATA AVAILABILITY
*APPENDIX TABLE 2: DATA AVAILABILITY BY TREATMENT STATUS

*** Indicator of data on weekly sales and profits being available
gen datasalesprofits=profitsweek~=. & salesweek~=.
egen anydatasalesprofits=max(datasalesprofits) if round==2|round==3, by(respid)
egen adata=max(datasalesprofits) if round==4|round==5, by(respid)
replace anydatasalesprofits=adata if round==4|round==5

eststo clear
areg interviewed r1_treated spillovertreat if round==2, cluster(r1_market1) a(r1_Strata)
sum interviewed if r1_treatedmarket==0 & e(sample) & round==2
estadd scalar mean = r(mean)
eststo tableA_1
areg interviewed r1_treated spillovertreat if round==3, cluster(r1_market1) a(r1_Strata)
sum interviewed if r1_treatedmarket==0 & e(sample) & round==3
estadd scalar mean = r(mean)
eststo tableA_2
areg anyinterview r1_treated spillovertreat if round==2, cluster(r1_market1) a(r1_Strata)
sum anyinterview if r1_treatedmarket==0 & e(sample) & round==2
estadd scalar mean = r(mean)
eststo tableA_3
areg interviewed r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum interviewed if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_4
areg interviewed r1_treated spillovertreat if round==5, cluster(r1_market1) a(r1_Strata)
sum interviewed if r1_treatedmarket==0 & e(sample) & round==5
estadd scalar mean = r(mean)
eststo tableA_5
areg anyinterview r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum anyinterview if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_6

areg dataonsurvival r1_treated spillovertreat if round==2, cluster(r1_market1) a(r1_Strata)
sum dataonsurvival if r1_treatedmarket==0 & e(sample) & round==2
estadd scalar mean = r(mean)
eststo tableA_7
areg dataonsurvival r1_treated spillovertreat if round==3, cluster(r1_market1) a(r1_Strata)
sum dataonsurvival if r1_treatedmarket==0 & e(sample) & round==3
estadd scalar mean = r(mean)
eststo tableA_8
areg anysurvivaldata r1_treated spillovertreat if round==3, cluster(r1_market1) a(r1_Strata)
sum anysurvivaldata if r1_treatedmarket==0 & e(sample) & round==3
estadd scalar mean = r(mean)
eststo tableA_9
areg dataonsurvival r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum dataonsurvival if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_10
areg dataonsurvival r1_treated spillovertreat if round==5, cluster(r1_market1) a(r1_Strata)
sum dataonsurvival if r1_treatedmarket==0 & e(sample) & round==5
estadd scalar mean = r(mean)
eststo tableA_11
areg anysurvivaldata r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum anysurvivaldata if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_12

areg datasalesprofits r1_treated spillovertreat if round==2, cluster(r1_market1) a(r1_Strata)
sum datasalesprofits if r1_treatedmarket==0 & e(sample) & round==2
estadd scalar mean = r(mean)
eststo tableA_13
areg datasalesprofits r1_treated spillovertreat if round==3, cluster(r1_market1) a(r1_Strata)
sum datasalesprofits if r1_treatedmarket==0 & e(sample) & round==3
estadd scalar mean = r(mean)
eststo tableA_14
areg anydatasalesprofits r1_treated spillovertreat if round==3, cluster(r1_market1) a(r1_Strata)
sum anydatasalesprofits if r1_treatedmarket==0 & e(sample) & round==3
estadd scalar mean = r(mean)
eststo tableA_15
areg datasalesprofits r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum datasalesprofits if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_16
areg datasalesprofits r1_treated spillovertreat if round==5, cluster(r1_market1) a(r1_Strata)
sum datasalesprofits if r1_treatedmarket==0 & e(sample) & round==5
estadd scalar mean = r(mean)
eststo tableA_17
areg anydatasalesprofits r1_treated spillovertreat if round==4, cluster(r1_market1) a(r1_Strata)
sum anydatasalesprofits if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean = r(mean)
eststo tableA_18

#delimit ;
esttab tableA_* using "output/Appendix7Table2DataAvailability.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(mean N, fmt(%9.3f %9.0g) labels("Mean" "Sample Size")) 
	title("Appendix Table 2: Data Availability by Treatment Status") addnotes("""") ;
#delimit cr



**** APPENDIX 8: LATE IMPACTS FOR PRIMARY OUTCOMES
* APPENDIX TABLE 3: LATE IMPACTS ON PRIMARY OUTCOMES
cap drop eattend
egen eattend=max(everattends), by(respid)
replace everattends=eattend if (round==4|round==5)
gen everattends_r23=everattends*r23
gen everattends_r45=everattends*r45

eststo clear
* Survival
xi: ivreg2  survives (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 round3 round4 round5 i.r1_Strata, r cluster(r1_market1)
eststo tableA5_1
* Last Day Sales
xi: ivreg2  salesday (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_salesday r1_salesday_miss round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_2
* Last Week Sales
xi: ivreg2  salesweek (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_salesweek r1_salesweek_miss round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_3
* Main Product Sales
xi: ivreg2  salesmainprod (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_salesmainprod r1_salesmainprod_miss round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_4
* Weekly Profits
xi: ivreg2  profitsweek (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_profitsweek  round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_5
* Profits from main product
xi: ivreg2  profmainprod (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_profmainprod r1_profmainprod_miss  round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_6
* Photo inventories
xi: ivreg2  photoinventories (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_photoinventories r1_photo_miss round4 i.r1_Strata if (round==2|round==4), cluster(r1_market1) 
eststo tableA5_7
* Profits and Sales Index
xi: ivreg2  profsalesindex (everattends_r23 everattends_r45=r1_treated_r23 r1_treated_r45) spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 i.r1_Strata, cluster(r1_market1) 
eststo tableA5_8

#delimit ;
esttab tableA5_* using "output/Appendix8Table3.csv", replace depvar legend label nonumbers
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Appendix Table 3: LATE Impacts on Primary Outcomes") addnotes("""") ;
#delimit cr

* version rounded to nearest integer
#delimit ;
esttab tableA5_* using "output/Appendix8Table3a.csv", replace depvar legend label nonumbers
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2, fmt(%9.3f %9.0g %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2")) 
	title("Appendix Table 3: LATE Impacts on Primary Outcomes") addnotes("""") ;
#delimit cr


**** APPENDIX 9: ROBUSTNESS CHECKS ON PRIMARY OUTCOMES
* APPENDIX TABLE 4: IS THE BUSINESS VISUALLY BIGGER AFTER THREE YEARS
eststo clear
areg biggerbus r1_treated spillovertreat  if round==4, cluster(r1_market1) a(r1_Strata)
sum biggerbus if r1_treatedmarket==0 & e(sample)
estadd scalar mean=r(mean)
eststo tableAP_1
areg biggerbus r1_treated spillovertreat  if round==4 & survives==1, cluster(r1_market1) a(r1_Strata)
sum biggerbus if r1_treatedmarket==0 & e(sample)
estadd scalar mean=r(mean)
eststo tableAP_2
areg biggerbus r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill  if round==4 & msmallmkt==0, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum biggerbus if r1_treatedmarket==0 & e(sample)
estadd scalar mean=r(mean)
eststo tableAP_3
areg biggerbus r1_mentored r1_mentor_spill r1_trainonly r1_trainonly_spill  if round==4 & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
sum biggerbus if r1_treatedmarket==0 & e(sample)
estadd scalar mean=r(mean)
eststo tableAP_4

#delimit ;
esttab tableAP_* using "output/Appendix9Table4.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(N pval, fmt( %9.0g %9.3f) labels( "Sample Size" "P-value")) 
	title("Appendix Table 4: Is the Business Visually Bigger After Three Years") addnotes("""") ;
#delimit cr


* APPENDIX TABLE 5: IMPACTS ON PRIMARY OUTCOMES CONDITIONAL ON SURVIVAL
***** Panel A: Direct and Spillover Effects of Training Assignment
eststo clear
* Last Day Sales
areg salesday r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesday r1_salesday_miss round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesday if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_2
* Last Week Sales
areg salesweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesweek r1_salesweek_miss round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_3
* Main Product Sales
areg salesmainprod r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_salesmainprod r1_salesmainprod_miss round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum salesmainprod if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_4
* Weekly Profits
areg profitsweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profitsweek  round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profitsweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_5
* Profits from main product
areg profmainprod r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profmainprod r1_profmainprod_miss  round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profmainprod if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_6
* Photo inventories
areg photoinventories r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_photoinventories r1_photo_miss round4 if (round==2|round==4) & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum photoinventories if r1_treatedmarket==0 & e(sample) & round==4
estadd scalar mean=r(mean)
eststo table4_7
* Profits and Sales Index
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo table4_8

#delimit ;
esttab table4_* using "output/Appendix9Table5panelA.csv", replace depvar legend label nonumbers
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Appendix Table 5: Impacts on Primary Outcomes Conditional on Survival - Panel A") addnotes("""") ;
#delimit cr

#delimit ;
esttab table4_* using "output/Appendix9Table5panelAa.csv", replace depvar legend label nonumbers
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps 
	stats(mean N pval1 pval2 pval3, fmt(%9.0f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Pure Control Group" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Appendix Table 5: Impacts on Primary Outcomes Conditional on Survival - Panel A") addnotes("""") ;
#delimit cr


***** Panel B: Mentoring and Training
*** Total sales in the last day
areg salesday r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesday r1_salesday_miss round5 if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_2
*** Total sales in the last week
areg salesweek r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesweek r1_salesweek_miss round5 if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_3
*** Total sales in the last week of product accounting for largest share of profits
areg salesmainprod r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_salesmainprod r1_salesmainprod_miss round5  if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_4
**** Profits
areg profitsweek r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profitsweek round5 if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_5
**** Mark-up profits on main product
areg profmainprod r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profmainprod r1_profmainprod_miss  round5 if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_6
**** Photo-valued inventories
areg photoinventories r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill if round==4 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_7
**** Profit and Sales Index
areg profsalesindex r1_mentored r1_trainonly r1_mentor_spill  r1_trainonly_spill r1_profsalesindex round5 if (round==4|round==5) & msmallmkt==0 & survives==1, cluster(r1_market1) a(r1_Strata)
test r1_mentored==r1_trainonly
estadd scalar pval=r(p)
eststo table4b_8

#delimit ;
esttab table4b_* using "output/Appendix9Table5panelB.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(N pval, fmt(%9.0g %9.3f) labels( "Sample Size" "P-value")) 
	title("Appendix Table 5: Impacts on Primary Outcomes Conditional on Survival - Panel B") addnotes("""") ;
#delimit cr
#delimit ;
esttab table4b_* using "output/Appendix9Table5panelBa.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.0f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(N pval, fmt(%9.0g %9.3f) labels( "Sample Size" "P-value")) 
	title("Appendix Table 5: Impacts on Primary Outcomes Conditional on Survival - Panel B") addnotes("""") ;
#delimit cr


* APPENDIX TABLE 6: ROBUSTNESS OF PRIMARY OUTCOME RESULTS
* Difference between reported inventories and photo
cap drop inventdiff
gen loginvent=log(inventories)
gen logphoto=log(photoinventories)
gen inventdiff=loginvent-logphoto if round==2|round==4

*** Alternative definition of survival: if died before, and not observed in round T, assume firm still dead
gen surv_alt=survives
gen deadinr2=1 if round==2 & survives==0
egen mdeadinr2=max(deadinr2), by(respid)
replace surv_alt=0 if surv_alt==. & round==3 & mdeadinr2==1
gen deadinr3=1 if round==3 & surv_alt==0
egen mdeadinr3=max(deadinr3), by(respid)
replace surv_alt=0 if surv_alt==. & round==4 & mdeadinr3==1
gen deadinr4=1 if round==4 & surv_alt==0
egen mdeadinr4=max(deadinr4), by(respid)
replace surv_alt=0 if surv_alt==. & round==5 & mdeadinr4==1

eststo clear
areg surv_alt r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum surv_alt if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_1
* Inverse Hyperbolic Sines of Sales and Profits
foreach var of varlist  r1_invsales r1_invprofits {
cap drop mr_`var'
egen mr_`var'=max(`var'), by(respid)
replace `var'=mr_`var' if (round==4|round==5)
}
areg invsales r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_invsales r1_salesweek_miss round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum invsales if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_2
areg invprofits r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_invprofits round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum invprofits if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_3

* Log of Last Week Sales
gen logsalesweek=log(salesweek)
gen logr1_salesweek=log(r1_salesweek)
areg logsalesweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 logr1_salesweek r1_salesweek_miss round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum logsalesweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_4

* Log Weekly Profits
gen logprofitsweek=log(profitsweek)
gen logr1_profitsweek=log(r1_profitsweek)
areg logprofitsweek r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 logr1_profitsweek  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum logprofitsweek if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_5
**** Impact on Number of Reporting Errors (Conditional on Survival)
areg totalerrors r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 logr1_salesweek r1_salesweek_miss round3 round4 round5 if survives==1, cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum totalerrors if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_6

* reporting of inventories
areg inventdiff r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45  round4 if survives==1 & (round==2|round==4), cluster(r1_market1) a(r1_Strata)
test r1_treated_r23==r1_treated_r45
estadd scalar pval1= r(p)
test spillovertreat_r23==spillovertreat_r45
estadd scalar pval2= r(p)
test r1_treated_r23==r1_treated_r45==0
estadd scalar pval3=r(p)
sum inventdiff if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableR_7

#delimit ;
esttab tableR_* using "output/Appendix9Table6.csv", replace depvar legend label nonumbers 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0f %9.3f %9.3f %9.3f) labels("Mean" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Appendix Table 6: Robustness of Primary Outcome Results") addnotes("""") ;
#delimit cr


**** APPENDIX 10: ROBUSTNESS TO EXCLUDING NEARBY MARKETS
*APPENDIX TABLE 7: ROBUSTNESS OF IMPACTS ON PROFITS AND SALES INDEX OF EXCLUDING MARKETS WITH OTHER MARKETS NEARBY
*** Exclude markets where mean foodshare less than 50% (10 markets omitted)
gen excludemarket=1 if r1_market1==1008|r1_market1==1059|r1_market1==1062|r1_market1==1082|r1_market1==1093|r1_market1==2002|r1_market1==2027|r1_market1==2031|r1_market1==2031|r1_market1==2044|r1_market1==2058

* Exclude markets where mean foodshare less than 70% (60 markets omitted)
gen excludemarket2=1 if excludemarket==1
#delimit ;
replace excludemarket2=1 if r1_market1==1009|r1_market1==1015|r1_market1==1016|r1_market1==1029|r1_market1==1030|r1_market1==1034|r1_market1==1041|r1_market1==1056|r1_market1==1091|r1_market1==1094|r1_market1==1095|
r1_market1==1099|r1_market1==2003|r1_market1==2004|r1_market1==2005|r1_market1==2010|r1_market1==2013|r1_market1==2015|r1_market1==2016|r1_market1==2029|r1_market1==2033|r1_market1==2035|r1_market1==2046|r1_market1==2047| 
r1_market1==2049|r1_market1==2053|r1_market1==2055|r1_market1==2057|r1_market1==3004|r1_market1==3011|r1_market1==3013|r1_market1==3016|r1_market1==2017|r1_market1==3018|r1_market1==3024|r1_market1==3025|r1_market1==3028| 
r1_market1==3031|r1_market1==3-46|r1_market1==3047|r1_market1==4009|r1_market1==4014|r1_market1==4037|r1_market1==4042|r1_market1==4059|r1_market1==4065|r1_market1==4070|r1_market1==4078|r1_market1==4080|r1_market1==4108| 
r1_market1==4111|r1_market1==4112;
#delimit cr

** drop 22 markets which within 2 km of closest other market
#delimit ;
gen closemarket=1 if r1_market1== 3002|r1_market1== 3006|r1_market1== 3015|r1_market1== 3019|r1_market1== 3021|r1_market1== 3024|r1_market1== 3026|r1_market1== 3046|r1_market1== 1029|r1_market1== 1063|
r1_market1== 1066|r1_market1== 1100|r1_market1== 2004|r1_market1== 2005|r1_market1== 2010|r1_market1== 2011|r1_market1== 2013|r1_market1== 2022|r1_market1== 2031|r1_market1== 2055|r1_market1== 4043|r1_market1== 4045;
#delimit cr

*** markets within 5km of another market
gen closemarket2=1 if closemarket==1
#delimit ;
replace closemarket2=1 if r1_market1==3004|r1_market1==3012|r1_market1==3013|r1_market1==3016|r1_market1==3017|r1_market1==3018|r1_market1==3022|r1_market1==3025|r1_market1==3028|r1_market1==3029|r1_market1==3030|
r1_market1==3031|r1_market1==3035|r1_market1==3036|r1_market1==3038|r1_market1==3043|r1_market1==3047|r1_market1==3048|r1_market1==1009|r1_market1==1015|r1_market1==1032|r1_market1==1057|r1_market1==1060|
r1_market1==1062|r1_market1==1091|r1_market1==1093|r1_market1==1094|r1_market1==1098|r1_market1==1099|r1_market1==2003|r1_market1==2006|r1_market1==2016|r1_market1==2020|r1_market1==2024|r1_market1==2027|
r1_market1==2029|r1_market1==2039|r1_market1==2044|r1_market1==2047|r1_market1==2050|r1_market1==2052|r1_market1==2057|r1_market1==2058|r1_market1==4007|r1_market1==4025|r1_market1==4026|r1_market1==4034|
r1_market1==4055|r1_market1==4057|r1_market1==4063|r1_market1==4083|r1_market1==4097|r1_market1==4113;
#delimit cr

* Profits and Sales Index (base case as in Table 2)
eststo clear
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5, cluster(r1_market1) a(r1_Strata)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableA_1

* Exclude markets where mean foodshare less than 50%
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 if (excludemarket==.), cluster(r1_market1) a(r1_Strata)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableA_2

* Exclude markets where mean foodshare less than 70%
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 if (excludemarket2==.), cluster(r1_market1) a(r1_Strata)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableA_3

* Exclude markets within 2km of another market
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 if (closemarket==.), cluster(r1_market1) a(r1_Strata)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableA_4

* Exclude markets within 2km of another market
areg profsalesindex r1_treated_r23 r1_treated_r45 spillovertreat_r23 spillovertreat_r45 r1_profsalesindex  round3 round4 round5 if (closemarket2==.), cluster(r1_market1) a(r1_Strata)
sum profsalesindex if r1_treatedmarket==0 & e(sample) & (round==4|round==5)
estadd scalar mean=r(mean)
eststo tableA_5

#delimit ;
esttab tableA_* using "output/Appendix10Table7.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N, fmt(%9.3f %9.0g) labels("Mean of ure Control Group" "Sample Size")) 
	title("Appendix Table 7: Robustness of Impact on Profits and Sales Index of Excluding Markets With Other Markets Nearby") addnotes("""") ;
#delimit cr

**** APPENDIX 11: SHARPENED Q-VALUES FOR MECHANISM IMPACTS
*APPENDIX TABLE 8: P-VALUES AND SHARPENED Q-VALUES FOR MECHANISMS
* This code generates BKY (2006) sharpened two-stage q-values as described in Anderson (2008), "Multiple Inference and Gender Differences in the Effects of Early Intervention: A Reevaluation of the Abecedarian, Perry Preschool, and Early Training Projects", Journal of the American Statistical Association, 103(484), 1481-1495

* BKY (2006) sharpened two-stage q-values are introduced in Benjamini, Krieger, and Yekutieli (2006), "Adaptive Linear Step-up Procedures that Control the False Discovery Rate", Biometrika, 93(3), 491-507

* Last modified: M. Anderson, 11/20/07
* Test Platform: Stata/MP 10.0 for Macintosh (Intel 32-bit), Mac OS X 10.5.1
* Should be compatible with Stata 10 or greater on all platforms
* Likely compatible with with Stata 9 or earlier on all platforms (remove "version 10" line below)

* 1 year
use "sharpenedq/pvalues_1year.dta", clear
version 10

****  INSTRUCTIONS:
****    Please start with a clear data set
****	When prompted, paste the vector of p-values you are testing into the "pval" variable
****	Please use the "do" button rather than the "run" button to run this file (if you use "run", you will miss the instructions at the prompts)

*pause on
set more off
/*
if _N>0 {
	display "Please clear data set before proceeding"
	display "After clearing, type 'q' to resume"
	pause
	}	

quietly gen float pval = .
*/

display "***********************************"
display "Please paste the vector of p-values that you wish to test into the variable 'pval'"
display	"After pasting, type 'q' to resume"
display "***********************************"

* pause

* Collect the total number of p-values tested

quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if pval~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order
pause off
save qval1yr, replace

* 3 years
use "sharpenedq/pvalues_3year.dta", clear
version 10

****  INSTRUCTIONS:
****    Please start with a clear data set
****	When prompted, paste the vector of p-values you are testing into the "pval" variable
****	Please use the "do" button rather than the "run" button to run this file (if you use "run", you will miss the instructions at the prompts)

*pause on
set more off
/*
if _N>0 {
	display "Please clear data set before proceeding"
	display "After clearing, type 'q' to resume"
	pause
	}	

quietly gen float pval = .
*/

display "***********************************"
display "Please paste the vector of p-values that you wish to test into the variable 'pval'"
display	"After pasting, type 'q' to resume"
display "***********************************"

* pause

* Collect the total number of p-values tested

quietly sum pval
local totalpvals = r(N)

* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

quietly gen int original_sorting_order = _n
quietly sort pval
quietly gen int rank = _n if pval~=.

* Set the initial counter to 1 

local qval = 1

* Generate the variable that will contain the BKY (2006) sharpened q-values

gen bky06_qval = 1 if pval~=.

* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


while `qval' > 0 {
	* First Stage
	* Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval'/(1+`qval')
	* Generate value q'*r/M
	gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max(reject_rank1)

	* Second Stage
	* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
	* Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
	* Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
	* Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2*rank
	* Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max(reject_rank2)

	* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
	* Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	

quietly sort original_sorting_order
pause off
foreach var of varlist pval-bky06_qval{
renam `var' `var'3
}
rename Table table
rename Measure measure

save qval3yrs, replace

use qval1yr, clear
merge 1:1 table measure using qval3yrs, nogenerate
sort original*
keep table measure pval* bky06*
export excel using "output/Appendix11Table8", firstrow(variables) replace


**** APPENDIX 12: NO SIGNIFICANT IMPACT ON MARKET PRICES OR INPUT COSTS
*APPENDIX TABLE 9: IMPACT ON KEY MARKET PRICES AND UNIT COSTS
use "FullCombinedData.dta", clear

***** Impact on prices
* prices truncated at 1st and 99th percentile
foreach var of varlist price1-price14 {
gen trunc_`var'=`var'
sum `var', de
replace trunc_`var'=r(p1) if `var'<r(p1)
replace trunc_`var'=r(p99) if `var'>r(p99) & `var'~=.
}

*** Standardize each price by round mean, then take average price of all products firm sells
foreach var of varlist price1-price14 {
sum trunc_`var' if round==4, de
gen demean_`var'=(trunc_`var'-r(mean))/r(sd)
sum trunc_`var' if round==5, de
replace demean_`var'=(trunc_`var'-r(mean))/r(sd) if round==5
}
egen pricez=rmean(demean_price1-demean_price14)

areg pricez r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
areg pricez r1_mentored  r1_trainonly r1_mentor_spill r1_trainonly_spill  if (round==4|round==5) & msmallmkt==0, cluster(r1_market1) a(r1_Strata)

eststo clear
areg price1 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum price1 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_1
areg price2 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum price2 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_2
areg price3 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum price3 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_3
areg price4 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum price4 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_4
areg price7 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum price7 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_7

* purchase costs truncated at 1st and 99th percentile
foreach var of varlist cost1-cost14 {
gen trunc_`var'=`var'
sum `var', de
replace trunc_`var'=r(p1) if `var'<r(p1)
replace trunc_`var'=r(p99) if `var'>r(p99) & `var'~=.
}

areg cost1 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum cost1 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_1a
areg cost2 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum cost2 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_2a
areg cost3 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum cost3 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_3a
areg cost4 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum cost4 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_4a
areg cost7 r1_treated spillovertreat if (round==4|round==5), cluster(r1_market1) a(r1_Strata)
sum cost7 if r1_treatedmarket==0 & e(sample) 
estadd scalar mean=r(mean)
eststo table9_7a


#delimit ;
esttab table9_* table9_*a using "output/Appendix12Table9.csv", replace depvar legend label nonumbers
	drop(_cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01) nogaps
	stats(mean N pval1 pval2 pval3, fmt(%9.3f %9.0g %9.3f %9.3f %9.3f) labels("Mean of Control Markets" "Sample Size" "Pval1" "Pval2" "Pval3")) 
	title("Appendix Table 9: Impacts on Key Market Prices and Unit Costs") addnotes("""") ;
#delimit cr

