********************************************************************************

********************************************************************************
**THIS DO-FILE CONSTRUCTS THE MASTER DATASETS USED IN THE ANALYSES
**Growing Markets through Business Training for Female Entrepreneurs: A Market-Level Randomized Experiment in Kenya
**November 20, 2017
**David McKenzie (dmckenzie@worldbank.org) and Susana Puerto
**The analysis was performed with Stata, version 14.2

*Note: Change the directory and paths to data used before running this do-file.

********************************************************************************

********************************************************************************

cd "/Users/Lu/Dropbox/AnnaLuisaProjects/KenyaDatatoAnonymize"

*********** Master dataset (baselines, rounds 1-4) ***********

**** Construct main outcomes for Round 4
use "FollowupData/r4r5publicuse.dta", clear


* Interviewed
gen interviewed=consent==1
egen anyinterview=max(interviewed), by(respid)

* Survives
gen survives=1 if sec2_3_==1|sec2_3_==2|sec2_3==4
replace survives=0 if sec2_3_==3
replace survives=0 if sec2_3_==5
* use attrition section for those who don't answer currently in business question
* those who died are not in business
replace survives=0 if reasonattr==6
replace survives=1 if survives==. & ownbiz==1
replace survives=0 if survives==. & ownbiz==0
replace survives=1 if survives==. & i_ownbiz==1
replace survives=0 if survives==. & i_ownbiz==0
replace survives=0 if survives==. & reasonattr_i=="BUSSINESS PERMANETLY CLOSED"
replace survives=0 if survives==. & reasonattr_i=="IN PRISON"
replace survives=0 if survives==. & reasonattr_i=="RESPONDENT LOCKED AWAY IN PRISON TILL 2017"
replace survives=0 if survives==. & reasonattr_i=="RESPONDENT IN PRISON"
replace survives=0 if survives==. & reasonattr_c=="RELOCATED TO DUBAI, OUT OF THE COUNTRY"
replace survives=0 if survives==. & reasonattr_c=="RELOCATED TO SUDAN"|reasonattr_c=="RESPONDENT RELOCATED TO DUBAI"|reasonattr_c=="RESPONDENT RELOCATED TO SAUDI ARABIA"|reasonattr_c=="SAUDI ARABIA"|reasonattr_c=="SAUDI ARABIA DUBAI"|reasonattr_c=="U.S.A"|reasonattr_c=="WENT TO SAUDI ARABIA"
#delimit ;
replace survives=0 if (respid==30170038|respid==40550004|respid==30490005|respid==30380029|respid==30430037|respid==40800018|respid== 40250023|respid==20220043|respid==10080045|respid==40740032|respid== 20500008|
respid==30470012|respid== 30460001|respid==40690013|respid==40660002|respid==30480006|respid==10090021|respid==20020012|respid==20030001|respid==40420032|respid==30200046|respid==10660021|respid==40700032|
respid==10150009|respid==20520038|respid==41010016|respid==10590008|respid== 30360015|respid==20150014|respid==20270034|respid==40420025|respid==30100028|respid==30250039|respid==20460030) & round==4 & survives==.;
replace survives=0 if (respid==10590008|respid==20020010|respid==20020012|respid==20070040|respid==20100024|respid==20120024|respid==20160034|respid==20580037|respid==40030032|respid==40430048|respid==40550004|
respid==40600022|respid==40660009|respid==40700019|respid==40740030|respid==40840038|respid==40970038|respid==41070022|respid==41070025|respid==41120030|respid==41130022) & round==5 & survives==.;
#delimit cr
gen dataonsurvival=survives~=.
egen anysurvivaldata=max(dataonsurvival), by(respid)

* round dummy
gen round5=round==5

***** Data on sales and profits
***** Sales in the last day
gen salesday=sec5_7a
* cleaning
replace salesday=. if sec5_7a==-999|sec5_7a==-888|sec5_7a==-555|sec5_7a==-666
* sales are zero if they were closed that day
replace salesday=0 if sec5_7a==-444|(sec5_7a>0 & sec5_7a<1)|sec5_7a==-44|sec5_7a==-441
replace salesday=. if salesday<0
* replace with best estimate if no answer
replace salesday=sec5_7b if sec5_7b>=0 & salesday==. & sec5_7b~=.

* replace with range answers if only answered those
replace salesday=0 if salesday==. & sec5_7c==1
replace salesday=100 if salesday==. & sec5_7c==2
replace salesday=250 if salesday==. & sec5_7c==3
replace salesday=350 if salesday==. & sec5_7c==4
replace salesday=450 if salesday==. & sec5_7c==5
replace salesday=600 if salesday==. & sec5_7c==6
replace salesday=850 if salesday==. & sec5_7c==7
replace salesday=1250 if salesday==. & sec5_7c==8
replace salesday=1750 if salesday==. & sec5_7c==9
replace salesday=2500 if salesday==. & sec5_7c==10
replace salesday=4000 if salesday==. & sec5_7c==11
sum salesday if salesday>5000 & salesday~=., de
gen medsales=r(p50)
replace salesday=medsales if salesday==. & sec5_7c==12
* sales are then zero for firms which don't survive
replace salesday=0 if survives==0
label var salesday "Sales in last day"

* truncate at 99th percentile, as per pre-analysis plan
sum salesday if round==4, de
replace salesday=r(p99) if salesday>r(p99) & salesday~=. & round==4
sum salesday if round==5, de
replace salesday=r(p99) if salesday>r(p99) & salesday~=. & round==5

*** Sales in the Last Week
gen salesweek=sec5_8a
* cleaning
replace salesweek=. if sec5_8a==-999|sec5_8a==-888|sec5_8a==-555|sec5_8a==-666|(sec5_8a>0.9 & sec5_8a<1)
* sales are zero if they were closed that day
replace salesweek=0 if sec5_8a==-444|(sec5_8a>0.4 & sec5_8a<0.5)|sec5_8a==-44
replace salesweek=. if salesweek<0
* replace with best estimate when prompted
replace salesweek=sec5_8b if salesweek==. & sec5_8b>=0 & sec5_8b~=.
* replace with range answers if only answered those
replace salesweek=0 if salesweek==. & sec5_8c==0
replace salesweek=500 if salesweek==. & sec5_8c==1
replace salesweek=1250 if salesweek==. & sec5_8c==2
replace salesweek=1750 if salesweek==. & sec5_8c==3
replace salesweek=2250 if salesweek==. & sec5_8c==4
replace salesweek=2750 if salesweek==. & sec5_8c==5
replace salesweek=3500 if salesweek==. & sec5_8c==6
replace salesweek=4500 if salesweek==. & sec5_8c==7
replace salesweek=6000 if salesweek==. & sec5_8c==8
replace salesweek=8500 if salesweek==. & sec5_8c==9
replace salesweek=11000 if salesweek==. & sec5_8c==10
replace salesweek=13000 if salesweek==. & sec5_8c==11
replace salesweek=15000 if salesweek==. & sec5_8c==12
replace salesweek=17000 if salesweek==. & sec5_8c==13
replace salesweek=19000 if salesweek==. & sec5_8c==14
sum salesweek if salesweek>=20000 & salesweek~=., de
gen medsalesw=r(p50)
replace salesweek=medsalesw if salesweek==. & sec5_8c==15

* sales are then zero for firms which don't survive
replace salesweek=0 if survives==0
label var salesweek "Sales in last week, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum salesweek if round==4, de
replace salesweek=r(p99) if salesweek>r(p99) & salesweek~=. & round==4
sum salesweek if round==5, de
replace salesweek=r(p99) if salesweek>r(p99) & salesweek~=. & round==5

*** Sales of main product
gen salesmainprod=sec5_12d*sec5_12e
replace salesmainprod=. if sec5_12d<0
replace salesmainprod=. if sec5_12e<0 & sec5_12e~=-444
replace salesmainprod=0 if sec5_12e==-444
replace salesmainprod=. if salesmainprod<0
* sales are then zero for firms which don't survive
replace salesmainprod=0 if survives==0
label var salesmainprod "Sales in last week from main product"
* truncate at 99th percentile, as per pre-analysis plan
sum salesmainprod if round==4, de
replace salesmainprod=r(p99) if salesmainprod>r(p99) & salesmainprod~=. & round==4
sum salesmainprod if round==5, de
replace salesmainprod=r(p99) if salesmainprod>r(p99) & salesmainprod~=. & round==5

*** Profits
*** Average weekly profits over last 2 weeks
gen prof1=sec5_9ai
replace prof1=. if prof1==-999|prof1==-888|prof1==-555|(prof1>0.8 & prof1<1)
replace prof1=0 if prof1==-444|(prof1>0.4 & prof1<0.5)|prof1==-44
replace prof1=sec5_9aii if prof1==. & sec5_9aii>=0 & sec5_9aii~=.
replace prof1=0 if prof1==. & sec5_9aiii==1
replace prof1=250 if prof1==. & sec5_9aiii==2
replace prof1=750 if prof1==. & sec5_9aiii==3
replace prof1=1250 if prof1==. & sec5_9aiii==4
replace prof1=1750 if prof1==. & sec5_9aiii==5
replace prof1=2250 if prof1==. & sec5_9aiii==6
replace prof1=2750 if prof1==. & sec5_9aiii==7
replace prof1=3500 if prof1==. & sec5_9aiii==8
replace prof1=4500 if prof1==. & sec5_9aiii==9
replace prof1=6000 if prof1==. & sec5_9aiii==10
replace prof1=8500 if prof1==. & sec5_9aiii==11
replace prof1=12500 if prof1==. & sec5_9aiii==12
sum prof1 if prof1>=15000 & prof1~=., de
replace prof1=r(p50) if prof1==. & sec5_9aiii==13
replace prof1=0 if survives==0

gen prof2=sec5_9bi
replace prof2=. if prof2==-999|prof2==-888|prof2==-555|(prof2>0.8 & prof2<1)
replace prof2=0 if prof2==-444|(prof2>0.4 & prof2<0.5)|prof2==-44
replace prof2=sec5_9bii if prof2==. & sec5_9bii>=0 & sec5_9bii~=.
replace prof2=0 if prof2==. & sec5_9biii==1
replace prof2=250 if prof2==. & sec5_9biii==2
replace prof2=750 if prof2==. & sec5_9biii==3
replace prof2=1250 if prof2==. & sec5_9biii==4
replace prof2=1750 if prof2==. & sec5_9biii==5
replace prof2=2250 if prof2==. & sec5_9biii==6
replace prof2=2750 if prof2==. & sec5_9biii==7
replace prof2=3500 if prof2==. & sec5_9biii==8
replace prof2=4500 if prof2==. & sec5_9biii==9
replace prof2=6000 if prof2==. & sec5_9biii==10
replace prof2=8500 if prof2==. & sec5_9biii==11
replace prof2=12500 if prof2==. & sec5_9biii==12
sum prof2 if prof2>=15000 & prof2~=., de
replace prof2=r(p50) if prof2==. & sec5_9biii==13
replace prof2=0 if survives==0

gen profitsweek=(prof1 + prof2)/2 if prof1~=. & prof2~=.
replace profitsweek=prof1 if prof2==.
replace profitsweek=prof2 if prof1==.
sum profitsweek if round==4, de
replace profitsweek=r(p99) if profitsweek>r(p99) & profitsweek~=. & round==4
sum profitsweek if round==5, de
replace profitsweek=r(p99) if profitsweek>r(p99) & profitsweek~=. & round==5
label var profitsweek "Average weekly profits over last 2 weeks"

**** Mark-up profits in last week of main product (again high item non-response issues)
gen profmainprod=(sec5_12d-sec5_12c)*sec5_12e
replace profmainprod=. if sec5_12e==-999|sec5_12e==-888|sec5_12e==-777|sec5_12e==-555|sec5_12d==-999|sec5_12e==-888|sec5_12e==-777|sec5_12e==-555
replace profmainprod=. if sec5_12c==-999|sec5_12c==-888|sec5_12c==-777|sec5_12c==-555
replace profmainprod=0 if sec5_12e==-444|sec5_12d==-444|sec5_12c==-444

* profits are then zero for firms which don't survive
replace profmainprod=0 if survives==0
label var profmainprod "Profits in last week from main product, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum profmainprod if round==4, de
replace profmainprod=r(p99) if profmainprod>r(p99) & profmainprod~=. & round==4
sum profmainprod if round==5, de
replace profmainprod=r(p99) if profmainprod>r(p99) & profmainprod~=. & round==5
* also truncate at bottom to remove influence of a few huge negative outliers
replace profmainprod=0 if profmainprod<0

*** Value of business inventories for sale, truncated at the 99th percentile
gen photoinventories=(TOTAL_GOODSSERVICES_1+TOTAL_GOODSSERVICES_2)/2
replace photoinventories=. if round==5
* replace cases where no photo taken as missing
replace photoinventories=. if round==4 & photoinventories==0 & comments_1~="" & comments_1~=" "
replace photoinventories=0 if survives==0
sum photoinventories if round==4, de
replace photoinventories=r(p99) if photoinventories>r(p99) & round==4 & photoinventories~=.

* second definition
gen photoinv2=(TOTAL_INVENTORY_1+TOTAL_INVENTORY_2)/2
replace photoinv2=. if round==5
replace photoinv2=. if photoinventories==.
replace photoinv2=0 if survives==0
sum photoinv2 if round==4, de
replace photoinv2=r(p99) if photoinv2>r(p99) & round==4 & photoinv2~=.

*** Photo shows business is bigger
gen biggerbus=ANALYSIS==1
replace biggerbus=. if ANALYSIS==.|ANALYSIS==0

****** Profits and Sales Index 
*** Note this is missing if salesweek and profitsweek variables are missing, but otherwise is average of whatever variables are not missing
* need to add in photo inventory data
	foreach var of varlist salesday salesweek salesmainprod profitsweek profmainprod photoinventories { 
		sum `var' if r1_treatedmarket==0
		local thismean = r(mean) 
		local thissd = r(sd) 
		di "`thismean'" 
		di "`thissd'" 
		cap drop z1_`var'
		gen z1_`var' = (`var'-`thismean')/(`thissd') 
	} 
	egen profsalesindex = rowmean(z1_salesday z1_salesweek z1_salesmainprod z1_profitsweek z1_profmainprod z1_photoinventories) 
	label var profsalesindex "Aggregate Index of Profits and Sales Outcomes"
    replace profsalesindex=. if salesweek==. & profitsweek==.

*** Inverse hyperbolic since transform
gen invsales=ln(salesweek+(((salesweek^2)+1)^(1/2)))
gen invprofits=ln(profitsweek+(((profitsweek^2)+1)^(1/2)))

*** Reporting Errors
gen error1=salesmainprod>salesweek
replace error1=0 if salesmainprod==.
gen error2=profmainprod>profitsweek
replace error2=0 if profmainprod==.
gen profworstweek=sec5_10
replace profworstweek=. if sec5_10==-999|sec5_10==-888|sec5_10==-777|sec5_10==-555
replace profworstweek=0 if sec5_10==-444
gen error3=profworstweek>profitsweek
replace error3=0 if profworstweek==.
gen error4=profitsweek>salesweek
replace error4=0 if profitsweek==.
gen error5=salesday>salesweek
replace error5=0 if salesday==.
gen error6=sec5_12d<sec5_12c
replace error6=0 if sec5_12d<0|sec5_12c<0|sec5_12c==.
egen totalerrors=rsum(error1 error2 error3 error4 error5 error6)
replace totalerrors=. if survives==0|survives==.
replace totalerrors=. if error1==. & error2==.

***** Prices and Input costs of most common products
for num 1/14: gen priceX=sec5_11bX if sec5_11bX>0
for num 1/14: gen costX=sec5_11cX if sec5_11cX>0
for num 1/14: gen markupX=log(priceX)-log(costX)


*** Hypothesis B1 variables
* B1: Employed for pay
gen employedforpay=survives==1
replace employedforpay=. if survives==.
replace employedforpay=1 if sec3_10==1
replace employedforpay=1 if sec10_1m>0 & sec10_1m~=.
replace employedforpay=1 if sec10_1l>0 & sec10_1l~=.
label var employedforpay "Employed for pay"

*B1 : Income from work
gen incomefromwork=profitsweek
replace incomefromwork=sec3_15 if  sec3_15>=0 & sec3_15~=.
replace incomefromwork=incomefromwork+sec5_21 if sec5_21>0 & sec5_21~=.
replace incomefromwork=incomefromwork+sec5_23b if sec5_23b>0 & sec5_23b~=.
label var incomefromwork "Income from all work"

* B2 empowerment
gen empower1=cond(sec10_2==2, 1, 0) if  sec10_2~=.
gen empower2=cond(sec9_1==1,1,0) if   sec9_1_~=.
gen empower3=cond(sec10_3_==1,1,0) if   sec10_3_~=.
gen empower4=cond(sec10_4a1<=2,1,0) if   sec10_4a1<=3
gen empower5=cond(sec10_4a2<=2,1,0) if   sec10_4a2<=3
gen empower6=cond(sec10_4a3<=2,1,0) if   sec10_4a3<=3
gen empower7=cond(sec10_4a4<=2,1,0) if   sec10_4a4<=3
gen empower8=cond(sec10_4a5<=2,1,0) if   sec10_4a5<=3
gen empower9=cond(sec10_4a6<=2,1,0) if   sec10_4a6<=3
gen empower10=cond(sec10_4a7<=2,1,0) if   sec10_4a7<=3
egen empowerment=rsum(empower1-empower10) 
replace empowerment=. if empower1==. & empower2==.
label var empowerment "Empowerment index (higher is more empowered)"

* B3: Subjective well-being
gen laddertoday=sec1_4
label var laddertoday "Ladder of life today"
gen ladder5years=sec1_5
label var ladder5years "Ladder of life in 5 years"
* MHI-5 - code so higher score is better mental health
gen mhi5=(6-sec1_6a)+(6-sec1_6b)+sec1_6c+sec1_6d+sec1_6e

* B4: Household Durable Asset Ownership
gen asset1=cond(sec10_5a==1,1,0) if sec10_5a<=2
gen asset2=cond(sec10_5b==1,1,0) if sec10_5b<=2
gen asset3=cond(sec10_5c==1,1,0) if sec10_5c<=2
gen asset4=cond(sec10_5d==1,1,0) if sec10_5d<=2
gen asset5=cond(sec10_5e==1,1,0) if sec10_5e<=2
gen asset6=cond(sec10_5f==1,1,0) if sec10_5f<=2
gen asset7=cond(sec10_5g==1,1,0) if sec10_5g<=2
gen asset8=cond(sec10_5h==1,1,0) if sec10_5h<=2
gen asset9=cond(sec10_5i==1,1,0) if sec10_5i<=2
gen asset10=cond(sec10_5j==1,1,0) if sec10_5j<=2
gen asset11=sec10_5k if sec10_5k>=0
gen asset12=sec10_5l if sec10_5l>=0
pca asset1-asset12 
predict assetindex 
label var assetindex "Household Durable Assets Index"

*** C2: Market-Level Averages
egen marketsales=mean(salesweek), by(market1 round)
egen marketprof=mean(profitsweek), by(market1 round)

*** D1: Business Knowledge and Practices
* Not asked in R4

***D2: Business Practices
* Round 4
foreach x of varlist sec7_1a-sec7_4h sec7_12-sec7_20 sec7_22_ sec7_6_ sec7_7 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & sec7_1a~=.
}
gen bp_m1=sec7_1a
replace bp_m1=0 if sec7_1a==3
gen bp_m2=sec7_1b
replace bp_m2=0 if sec7_1b==3
gen bp_m3=sec7_1c
replace bp_m3=. if sec7_1c==3
gen bp_m4=sec7_1d
replace bp_m4=0 if sec7_1d==3
replace bp_m4=. if sec7_1d==4
gen bp_m5=sec7_1e
replace bp_m5=0 if sec7_1e==3
replace bp_m5=. if sec7_1e==4
gen bp_m6=sec7_2_ if sec7_2_<=1
gen bp_m7=sec7_3_ if sec7_3_<=1

gen bp_b1=sec7_6_ if sec7_6_<=1
gen bp_b2=sec7_7_ if sec7_7_<=1
gen bp_b3=0 if sec7_8_==4
replace bp_b3=1 if sec7_8_<=3
replace bp_b3=1 if sec7_7_==0

foreach x of varlist sec7_13_-sec7_15_  { 
replace `x' = 0 if sec7_12_==0
}
foreach x of varlist sec7_13_-sec7_20_  { 
replace `x' = . if `x'>1
}
gen bp_r1=sec7_12_
gen bp_r2=sec7_13_
gen bp_r3=sec7_14_
gen bp_r4=sec7_15_
gen bp_r5=sec7_16_
gen bp_r6=sec7_17_
gen bp_r7=sec7_18_
gen bp_r8=sec7_20_ 
gen bp_f1=sec7_21_==4
replace bp_f1=. if sec7_21_==.
gen bp_f2=sec7_22_ 
gen bp_f3=1 if sec7_22a==4
replace bp_f3=0 if sec7_22a<=3|bp_f2==0
gen bp_f4=1 if sec7_23==2
replace bp_f4=0 if sec7_23==1
gen bp_f5=0 if sec7_24_~=""
replace bp_f5=1 if sec7_24_=="1"|sec7_24_=="1 2"|sec7_24_=="1 2 3"|sec7_24_=="1 2 3 4"|sec7_24_=="1 2 4"|sec7_24_=="1 2 4 6"|sec7_24_=="1 3"|sec7_24_=="1 3 4"|sec7_24_=="1 3 4 6"|sec7_24_=="1 4"|sec7_24_=="1 4 6"

gen bp_f6=0 if sec7_24_~=""
replace bp_f6=1 if sec7_24_=="2"|sec7_24_=="1 2"|sec7_24_=="1 2 3"|sec7_24_=="1 2 3 4"|sec7_24_=="1 2 4"|sec7_24_=="1 2 4 6"|sec7_24_=="2 3"|sec7_24_=="2 3 4"|sec7_24_=="2 3 4 6"|sec7_24_=="2 4"|sec7_24_=="2 4 6"

gen bp_f7=0 if sec7_24_~=""
replace bp_f7=1 if sec7_24_=="3"|sec7_24_=="2 3"|sec7_24_=="1 2 3"|sec7_24_=="1 2 3 4"|sec7_24_=="2 3 4"|sec7_24_=="2 3 4 6"|sec7_24_=="1 3"|sec7_24_=="1 3 4"|sec7_24_=="1 3 4 6"|sec7_24_=="3 4"|sec7_24_=="3 4 6"

gen bp_f8=0 if sec7_24_~=""
replace bp_f8=1 if sec7_24_=="4"|sec7_24_=="3 4"|sec7_24_=="2 4"|sec7_24_=="1 2 3 4"|sec7_24_=="2 3 4"|sec7_24_=="2 3 4 6"|sec7_24_=="1 3 4"|sec7_24_=="1 3 4 6"|sec7_24_=="3 4"|sec7_24_=="3 4 6"|sec7_24_=="4 6"|sec7_24_=="1 2 4"|sec7_24_=="1 2 4 6"|sec7_24_=="1 4"|sec7_24_=="1 4 6"|sec7_24_=="2 4 6"

egen marketingscore=rmean(bp_m1 bp_m2 bp_m3 bp_m4 bp_m5 bp_m6 bp_m7)
label var marketingscore "Proportion of marketing practices used"
egen stockscore=rmean(bp_b1 bp_b2 bp_b3)
label var stockscore "Proportion of buying and stock control practices used"
egen recordscore=rmean(bp_r1 bp_r2 bp_r3 bp_r4 bp_r5 bp_r6 bp_r7 bp_r8)
label var recordscore "Proportion of record-keeping practices used"
egen planningscore=rmean(bp_f1-bp_f8)
label var planningscore "Proportion of financial planning practices used"
egen totalscore=rmean(bp_m1-bp_f8)
label var totalscore "Business Practices Score"


*** D2 - customer acquisition, and gaining and losing customers
* Round 2 - number of customers
gen numcustomers=sec5_15_
replace numcustomers=. if sec5_15_<0
replace numcustomers=2.5 if numcustomers==. & sec5_15a==1
replace numcustomers=7.5 if numcustomers==. & sec5_15a==2
replace numcustomers=15 if numcustomers==. & sec5_15a==3
replace numcustomers=25 if numcustomers==. & sec5_15a==4
replace numcustomers=35 if numcustomers==. & sec5_15a==5
replace numcustomers=45 if numcustomers==. & sec5_15a==6
replace numcustomers=62.5 if numcustomers==. & sec5_15a==7
replace numcustomers=87.5 if numcustomers==. & sec5_15a==8
replace numcustomers=150 if numcustomers==. & sec5_15a==9
replace numcustomers=250 if numcustomers==. & sec5_15a==10
sum numcustomers if numcustomers>300 & numcustomers~=., de
replace numcustomers=r(p50) if numcustomers==. & sec5_15a==11
* customers are zero for those not in business
replace numcustomers=0 if survive==0
* truncate at 99th percentile
sum numcustomers if round==4, de
replace numcustomers=r(p99) if numcustomers>r(p99) & numcustomers~=. & round==4
sum numcustomers if round==5, de
replace numcustomers=r(p99) if numcustomers>r(p99) & numcustomers~=. & round==5
label var numcustomers "Number of customers in the past week"

* Gained a Customer
gen gainednewcustomer=sec5_16a==1
replace gainednewcustomer=. if sec5_16a==.
replace gainednewcustomer=0 if survives==0
label var gainednewcustomer "Gained new customer in past 3 months"
* Lost a customer
gen lostcustomer=sec5_16b==1
replace lostcustomer=. if sec5_16b==.
replace lostcustomer=1 if survives==0
label var lostcustomer "Lost a regular customer in past 3 months"


*** D3: reacting to down times
* Ratio of worst week profits to current week
gen ratioprof=profworstweek/profitsweek
sum ratioprof if round==4, de
replace ratioprof=r(p1) if ratioprof<r(p1) & round==4
replace ratioprof=r(p99) if ratioprof>r(p99) & ratioprof~=. & round==4
sum ratioprof if round==5, de
replace ratioprof=r(p1) if ratioprof<r(p1) & round==5
replace ratioprof=r(p99) if ratioprof>r(p99) & ratioprof~=. & round==5
label var ratioprof "Ratio of worst to current week profits"
* Monitor records to see if sales increasing or decreasing for a particular product
gen monitorrecs=sec7_15_==1
replace monitorrecs=. if sec7_15_==.
replace monitorrecs=0 if survives==0
label var monitorrecs "Uses records to see if sales increasing or decreasing"


*** D4 accessing financing and building up inventories and capital
gen receivedloan=sec4_11a1==1|sec4_11a2==1
replace receivedloan=. if sec4_10==.
label var receivedloan "Received loan from bank or microfinance"

gen inventories=sec5_4_
replace inventories=. if inventories<0
replace inventories=0 if sec5_3_==2
replace inventories=0 if survives==0
sum inventories if round==4, de
replace inventories=r(p99) if inventories>r(p99) & inventories~=.
label var inventories "Value of inventories"

foreach var of varlist sec5_2_a1 sec5_2_a2 sec5_2_a3 sec5_2_a4 {
replace `var'=. if `var'<0
}
gen ownedcapital=sec5_2_a1+sec5_2_a2+sec5_2_a3+sec5_2_a4 
replace ownedcapital=0 if survives==0
sum ownedcapital if round==4, de
replace ownedcapital=r(p99) if ownedcapital>r(p99) & ownedcapital~=.
label var ownedcapital "Value of capital"

*** D5: inventory losses and stock management
gen fractionstocklost=sec5_4a/inventories
replace fractionstocklost=. if sec5_4a<0
sum fractionstocklost if round==4, de
replace fractionstocklost=r(p99) if fractionstocklost>r(p99) & fractionstocklost~=.
label var fractionstocklost "Fraction of stock lost to spoilage"

gen bulkdiscount=sec5_4b==1
replace bulkdiscount=. if sec5_4b==.
replace bulkdiscount=0 if survives==0
label var bulkdiscount "Received bulk discount when purchasing materials"

gen prodcostchange=100*(sec5_12c-r1_costmainproduct)/r1_costmainproduct
replace prodcostchange=. if sec5_12c<0
sum prodcostchange if round==4, de
replace prodcostchange=r(p5) if prodcostchange<r(p5)  & round==4
replace prodcostchange=r(p95) if prodcostchange>r(p95) & prodcostchange~=. & round==4
sum prodcostchange if round==5, de
replace prodcostchange=r(p5) if prodcostchange<r(p5)  & round==5
replace prodcostchange=r(p95) if prodcostchange>r(p95) & prodcostchange~=. & round==5
label var prodcostchange "Production cost change"

*** D6: hours worked, self-efficacy, and attitudes
gen laborhours=sec4_1a
replace laborhours=0 if laborhours==-444
replace laborhours=. if laborhours<0
replace laborhours=0 if survives==0

sum laborhours if round==4, de
replace laborhours=r(p99) if laborhours>r(p99) & laborhours~=.
label var laborhours "Labor hours in last week"

* self-efficacy and GET attitude not asked this round.

*** D7: networking and working together
gen belongwomenassoc=cond(sec6_1a2==1,1,0) if sec6_1a2<=2
label var belongwomenassoc "Belong to a women's association"
gen discussbusiness=sec_6_2_ if sec_6_2_>=0
sum discussbusiness if round==4, de
replace discussbusiness=r(p99) if discussbusiness>=r(p99) & discussbusiness~=.
label var discussbusiness "Number of other women they discuss business with"
gen worktogether=cond(sec_6_3_==1, 1, 0) if sec_6_3_<=2
label var worktogether "Works together with other women to get discount or buy materials"

** outcome suggested by qualitative work: membership of Roscas/Merry-go-rounds
cap drop belongmerrygo
gen belongmerrygo=cond(sec6_1a1==1,1,0) if sec6_1a1<=2
label var belongmerrygo "Belong to a merry-go-round"


*** Additional outcomes
* open business at fixed time
gen openatfixedtime=sec41c==1
replace openatfixedtime=. if sec41c==.
label var openatfixedtime "Open business at set time"

* number of employees
gen fulltimepaid=sec4_5ia
replace fulltimepaid=0 if sec4_4==2
replace fulltimepaid=0 if survives==0
label var fulltimepaid "Number of full-time paid workers"
gen parttimepaid=sec4_5ib
replace parttimepaid=0 if sec4_4==2
replace parttimepaid=0 if survives==0
label var parttimepaid "Number of part-time paid workers"

* registered
gen formal=sec4_6==1
replace formal=. if sec4_6==.
replace formal=0 if survives==0
label var formal "Business formally registered"

* business bank account
gen businessbankaccount=sec4_7==1
replace businessbankaccount=. if sec4_7==.
replace businessbankaccount=0 if survives==0
label var businessbankaccount "Has a business bank account"

* worked with a mentor
gen workedmentor=sec8_1==1
replace workedmentor=. if sec8_1==.
label var workedmentor "Worked with a mentor"
gen programmentor=sec8_2==1
replace programmentor=. if workedmentor==.
label var programmentor "Worked with mentor assigned through program"

* mentoring questions
rename sec8* r4_sec8*

* shown a record book with entries
gen observedrecords=sec11_0a==1 & sec11_0b==1
replace observedrecords=. if sec11_0a==.
label var observedrecords "Observe record book being kept"

* observed workers
gen observedworkers=sec11_2_ if sec11_2_>=0
label var observedworkers "Observed workers"


rename sec5_25 r4_sec5_25


*** Indicators of innovation and change in activity
gen changedactivity=sec2_3_==2
gen introducenewproduct=sec5_13==1 if round==4 & sec5_13_~=.
label var introducenewproduct "Introduced new product"
rename sec5_14_ r4_sec5_14 
rename sec5_14a r4_sec5_14a

****** Use of other labor
gen anyotherworker=cond(sec4_4_==1,1,0) if sec4_4_<=2 & round==4
replace anyotherworker=0 if survives==0 & round==4
label var anyotherworker "Anyone else work in business"
gen paidworkers=0 
replace paidworkers=sec4_5b1 if sec4_5f1==1|sec4_5f1==2
replace paidworkers=paidworkers+sec4_5b2 if sec4_5f2==1|sec4_5f2==2
replace paidworkers=paidworkers+sec4_5b3 if sec4_5f3==1|sec4_5f3==2
replace paidworkers=paidworkers+sec4_5b4 if sec4_5f4==1|sec4_5f4==2
replace paidworkers=paidworkers+sec4_5b5 if sec4_5f5==1|sec4_5f5==2
replace paidworkers=paidworkers+sec4_5b6 if sec4_5f6==1|sec4_5f6==2
replace paidworkers=. if round==5
replace paidworkers=. if round==4 & anyotherworker==.


** Keep constructed variables to append in with other rounds
#delimit ;
keep respid round anyinterview interviewed r1_treatedmarket r1_treated interviewed survives dataonsurvival anysurvivaldata salesday salesweek salesmainprod profitsweek profmainprod photoinventories photoinv2 biggerbus profsalesindex
invsales invprofits totalerrors price1-price14 cost1-cost14 markup1-markup14
employedforpay incomefromwork empowerment laddertoday ladder5years mhi5 assetindex 
marketsales marketprof marketingscore stockscore recordscore planningscore totalscore numcustomers gainednewcustomer lostcustomer ratioprof monitorrecs
receivedloan inventories ownedcapital fractionstocklost bulkdiscount prodcostchange laborhours belongwomenassoc discussbusiness worktogether belongmerrygo
openatfixedtime fulltimepaid parttimepaid formal businessbankaccount sec5_25 workedmentor programmentor r4_sec8* observedrecords observedworkers round5
total_matching_session total_groupmentoring total_individual_meeting totalmentoring anymentoringattend
sec2_4 sec2_4a changedactivity sec5_12a sec5_12ai r4_sec5_14 r4_sec5_14a introducenewproduct anyotherworker paidworkers
;
#delimit cr
sort respid round
save "R4R5data.dta", replace


**** Construct variables for Rounds 2 and 3

*Merge R2R3 with baseline data and the R2 photo data:

*** Rename identifying variable in public use baseline dataset
use "Baseline/AllBaselineKenyaPublicUse.dta", clear
gen double respid=respondent_id
cap drop _merge
sort respid
save "R1publicuse.dta", replace


*** Merge photo data together with baseline dataset
use "FollowupData/PhotoInventoryData_r2_public.dta", clear
duplicates drop respid, force
destring respid, force replace
sort respid
merge respid using R1publicuse.dta
keep if _merge==3
drop _merge
sort respid
save "R1publicuse.dta", replace

* merge with R2R3 data
merge 1:m respid using "FollowupData/r2r3publicuse2.dta"

* drop those not in experimental sample
drop if _merge==2
drop _merge

* save full combined data
sort respid
save FullCombinedDatar2r3.dta, replace

* generate number in the market
egen nummarket=count(r1_respondent_id), by(r1_market1)
egen numtreated=sum(r1_treated), by(r1_market1)
egen numattend=sum(r1_everattends), by(r1_market1)

cap drop _merge
sort r1_market1
merge r1_market1 using "newIntMarkets.dta"
label var newTreat "Mentoring Intervention Market"
* how many firms are in mentoring markets?
tab r1_treated if newTreat==1

* Survivorship defined in R2 and R3
**** Survey response rates and survival *********
* Interviewed
gen interviewed=consent==1
replace interviewed=ss_consent==1 if round==3
egen anyinterview=max(interviewed), by(respid)

* Survives
* Round 2 data
gen survives=1 if stillinbiz==1
replace survives=0 if stillinbiz==2
* individuals who died are not in business
replace survives=0 if reasonattr=="6"
replace survives=1 if sec2_3<=2
replace survives=0 if sec2_3==3
* individuals who claim never to have run a business 
replace survives=0 if sec2_2_=="-777"
replace survives=0 if reasonattr_a=="BUSY AND CLOSED BUSINES"
replace survives=0 if respid==20280019|respid==20460012 |respid==20520038|respid==20520003|respid==30290021|respid==40060023



* Round 3 data
replace survives=1 if ss_stillinbiz==1 
replace survives=0 if ss_stillinbiz==2
replace survives=1 if ss_sec2_3_<=2
replace survives=0 if ss_sec2_3_==3
* individuals who died are not in business
replace survives=0 if ss_reasonattr==6
replace survives=0 if ss_reasonattr_a=="LEFT BUSSINESS NOW ON EMPLOYEMENT"
replace survives=0 if ss_reasonattr_a=="SHE IS MARRIED AND  NOT CONDUCTING ANY BUSINESS  REFUSED TO PARTICIPATE."
replace survives=0 if ss_reasonattr_a=="SHE SAID THAT SHE IS JUST NOT INTRESTED AND HAD LEFT BUSINESS FOR HOUSE MAID  JOB."
replace survives=0 if ss_reasonattr_a=="LEFT BUSSINESS NOW ON EMPLOYEMENT"
* individuals who went to saudi arabia not in business
replace survives=0 if ss_remarks=="WENT TO SAUDI ARABIA"
replace survives=0 if ss_remarks=="THE RESPONDENT IS DECEASED."
gen ss_remark_str=substr(ss_remarks, 1, 90)
replace survives=0 if ss_remark_str=="THE HUSBAND DID NOT ALLOW US TO COMMUNICATE WITH THE RESPONDENT, HE SAID HE CLOSED THE BUS"
replace survives=0 if ss_remark_str=="CLOSED BUSINES AND WENT TO MOMBASA"
replace survives=0 if ss_remark_str=="WENT TO SAUDI ARABIA."
replace survives=0 if ss_remark_str=="THE RESPONDENTS NUMBER IS OFF, BUSINESS CLOSED, ALTERNATIVE NUMBER(SPOUSE) NOT PROVIDING R"
replace survives=0 if ss_remark_str=="THE RESPONDENT CLOSED BUSINESS, HAS RESCHEDULED INTERVIEW SEVERAL TIMES, AND WHEN TRIED FO"
gen dataonsurvival=survives~=.
egen anysurvivaldata=max(dataonsurvival), by(respid)

* how many firms in mentoring markets?
tab r1_treated if newTreat==1 & round==2

* how many firms in mentoring markets who survive in Round 2?
tab r1_treated if newTreat==1 & survives==1  & round==2

* how many firms in mentoring markets who not surviving or unknown in Round 2?
tab r1_treated if newTreat==1 & survives~=1 & round==2

* how many firms and markets in training but not mentoring?
tab r1_treated if newTreat==0 & r1_treatedmarket==1 & round==2
distinct r1_market1 if newTreat==0 & r1_treatedmarket==1 & round==2
* split this by survives or not
tab r1_treated if newTreat==0 & r1_treatedmarket==1 & round==2 & survives==1
tab r1_treated if newTreat==0 & r1_treatedmarket==1 & round==2 & survives==0

*firms and markets too small for mentoring in treatment markets
tab r1_treated if newTreat==. & r1_treatedmarket==1 & round==2
distinct r1_market1 if newTreat==. & r1_treatedmarket==1 & round==2

* firms and markets in pure control markets with 16+ people
distinct r1_market1 if nummarket>=16 & r1_treatedmarket==0 & round==2

* firms and markets in pure control markets with <16 people
distinct r1_market1 if nummarket<16 & r1_treatedmarket==0 & round==2




************ From R2.R3 analysis ********************
**** Spillover treatment variable
gen spillovertreat=r1_treated==0 & r1_treatedmarket==1
replace r1_treated=0 if r1_treatedmarket==0

* Make sure we have treatment variables defined for round 3
egen r1_tm=max(r1_treated), by(respid)
replace r1_treated=r1_tm if round==3
egen sp_m=max(spillovertreat), by(respid)
replace spillovertreat=sp_m if round==3
egen mark_m=max(r1_market1), by(respid)
replace r1_market1=mark_m if round==3
egen r1_mm=max(r1_treatedmarket), by(respid)
replace r1_treatedmarket=r1_mm if round==3
egen r1_S=max(r1_Strata), by(respid)
replace r1_Strata=r1_S if round==3
egen r1_r=max(r1_region), by(respid)
replace r1_region=r1_r if round==3
egen r1_s=max(r1_salesday), by(respid)
replace r1_salesday=r1_s if round==3
egen r1_s1=max(r1_salesday_miss), by(respid)
replace r1_salesday_miss=r1_s1 if round==3
egen r1_s2=max(r1_salesweek), by(respid)
replace r1_salesweek=r1_s2 if round==3
egen r1_s3=max(r1_salesweek_miss), by(respid)
replace r1_salesweek_miss=r1_s3 if round==3
egen r1_p=max(r1_profitsweek), by(respid)
replace r1_profitsweek=r1_p if round==3
egen r1_s4=max(r1_salesmainprod), by(respid)
replace r1_salesmainprod=r1_s4 if round==3
egen r1_s5=max(r1_salesmainprod_miss), by(respid)
replace r1_salesmainprod_miss=r1_s5 if round==3
egen r1_p2=max(r1_profmainprod), by(respid)
replace r1_profmainprod=r1_p2 if round==3
egen r1_p3=max(r1_profmainprod_miss), by(respid)
replace r1_profmainprod_miss=r1_p3 if round==3
egen m_newIntTreat=max(newIntTreat), by(respid)
replace newIntTreat=m_newIntTreat if round==3
egen m_newIntStrata=max(newIntStrata), by(respid)
replace newIntStrata=m_newIntStrata if round==3
egen m_r1_strata1 =max(r1_strata1 ), by(respid)
replace r1_strata1 =m_r1_strata1  if round==3

* round dummy
gen round3=round==3

*** Baseline variables for market level comparison
gen retail=b_business_nature==3
gen services=b_business_nature==2
replace retail=. if b_business_nature==.
replace services=. if b_business_nature==.
gen registered=b_s1_3==1
replace registered=. if b_s1_3==.
gen previoustraining=cond(b_s7_1==1,1,0) if b_s7_1~=.


**** Hypothesis A1_H: Heterogeneity in Survivorship Effect
gen lowbaseprof=q16_profit<=1000
egen m_r1_totalscore=max(r1_totalscore), by(respid)
replace r1_totalscore=m_r1_totalscore if round==3
gen highbasemngt=r1_totalscore>11 & r1_totalscore~=.

gen lowbaseprof_treat=r1_treated*lowbaseprof
gen lowbaseprof_spillover=spillovertreat*lowbaseprof
gen lowbaseprof_round3=lowbaseprof*round3
gen highbasemngt_treat=r1_treated*highbasemngt
gen highbasemngt_spillover=spillovertreat*highbasemngt
gen highbasemngt_round3=highbasemngt*round3

***** Data on sales and profits
***** Sales in the last day
gen salesday=sec5_7_
* cleaning
replace salesday=. if sec5_7_==-999|sec5_7_==-888|sec5_7_==-555|sec5_7_==-666
* sales are zero if they were closed that day
replace salesday=0 if sec5_7_==-444|(sec5_7_>0 & sec5_7_<1)
replace salesday=. if salesday<0
* replace with range answers if only answered those
replace salesday=100 if salesday==. & sec5_7a==1
replace salesday=250 if salesday==. & sec5_7a==2
replace salesday=350 if salesday==. & sec5_7a==3
replace salesday=450 if salesday==. & sec5_7a==4
replace salesday=600 if salesday==. & sec5_7a==5
replace salesday=850 if salesday==. & sec5_7a==6
replace salesday=1250 if salesday==. & sec5_7a==7
replace salesday=1750 if salesday==. & sec5_7a==8
sum salesday if salesday>2000 & salesday~=., de
gen medsales=r(p50)
replace salesday=medsales if salesday==. & sec5_7a==9
* sales are then zero for firms which don't survive
replace salesday=0 if survives==0
label var salesday "Sales in last day, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum salesday, de
replace salesday=r(p99) if salesday>r(p99) & salesday~=.

replace salesday=ss_sec5_7_ if round==3
* cleaning
replace salesday=. if (ss_sec5_7_==-999|ss_sec5_7_==-888|ss_sec5_7_==-555|ss_sec5_7_==-666) & round==3
* sales are zero if they were closed that day
replace salesday=0 if ss_sec5_7_==-444 & round==3
replace salesday=. if salesday<0 & round==3
* replace with range answers if only answered those
replace salesday=100 if salesday==. & ss_sec5_7a==1 & round==3
replace salesday=250 if salesday==. & ss_sec5_7a==2 & round==3
replace salesday=350 if salesday==. & ss_sec5_7a==3 & round==3
replace salesday=450 if salesday==. & ss_sec5_7a==4 & round==3
replace salesday=600 if salesday==. & ss_sec5_7a==5 & round==3
replace salesday=850 if salesday==. & ss_sec5_7a==6 & round==3
replace salesday=1250 if salesday==. & ss_sec5_7a==7 & round==3
replace salesday=1750 if salesday==. & ss_sec5_7a==8 & round==3
sum salesday if salesday>2000 & salesday~=. & round==3, de 
replace medsales=r(p50) if round==3
replace salesday=medsales if salesday==. & ss_sec5_7a==9 & round==3
* sales are then zero for firms which don't survive
replace salesday=0 if survives==0
label var salesday "Sales in last day"
* truncate at 99th percentile, as per pre-analysis plan
sum salesday  if round==3, de
replace salesday=r(p99) if salesday>r(p99) & salesday~=. & round==3

*** Sales in the Last Week
* round 2
gen salesweek=sec5_8_
* cleaning
replace salesweek=. if sec5_8_==-999|sec5_8_==-888|sec5_8_==-555|sec5_8_==-666|(sec5_8_>0.9 & sec5_8_<1)
* sales are zero if they were closed that day
replace salesweek=0 if sec5_8_==-444|(sec5_8_>0.4 & sec5_8_<0.5)
replace salesweek=. if salesweek<0
* replace with range answers if only answered those
replace salesweek=500 if salesweek==. & sec5_8a==1
replace salesweek=1250 if salesweek==. & sec5_8a==2
replace salesweek=1750 if salesweek==. & sec5_8a==3
replace salesweek=2250 if salesweek==. & sec5_8a==4
replace salesweek=2750 if salesweek==. & sec5_8a==5
replace salesweek=3500 if salesweek==. & sec5_8a==6
replace salesweek=4500 if salesweek==. & sec5_8a==7
replace salesweek=6000 if salesweek==. & sec5_8a==8
replace salesweek=8500 if salesweek==. & sec5_8a==9
sum salesweek if salesweek>=10000 & salesweek~=., de
gen medsalesw=r(p50)
replace salesweek=medsalesw if salesweek==. & sec5_8a==10
* sales are then zero for firms which don't survive
replace salesweek=0 if survives==0
label var salesweek "Sales in last week, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum salesweek, de
replace salesweek=r(p99) if salesweek>r(p99) & salesweek~=.
* round 3
replace salesweek=ss_sec5_8_ if round==3
* cleaning
replace salesweek=. if (ss_sec5_8_==-999|ss_sec5_8_==-888|ss_sec5_8_==-555|ss_sec5_8_==-666) & round==3
* sales are zero if they were closed that week
replace salesweek=0 if ss_sec5_8_==-444 & round==3
replace salesweek=. if salesweek<0 & round==3
* replace with range answers if only answered those
replace salesweek=500 if salesweek==. & ss_sec5_8a==1 & round==3
replace salesweek=1250 if salesweek==. & ss_sec5_8a==2 & round==3
replace salesweek=1750 if salesweek==. & ss_sec5_8a==3 & round==3
replace salesweek=2250 if salesweek==. & ss_sec5_8a==4 & round==3
replace salesweek=2750 if salesweek==. & ss_sec5_8a==5 & round==3
replace salesweek=3500 if salesweek==. & ss_sec5_8a==6 & round==3
replace salesweek=4500 if salesweek==. & ss_sec5_8a==7 & round==3
replace salesweek=6000 if salesweek==. & ss_sec5_8a==8 & round==3
replace salesweek=8500 if salesweek==. & ss_sec5_8a==9 & round==3
sum salesweek if salesweek>=10000 & salesweek~=. & round==3, de
replace medsalesw=r(p50) if round==3
replace salesweek=medsalesw if salesweek==. & ss_sec5_8a==10 & round==3
* sales are then zero for firms which don't survive
replace salesweek=0 if survives==0
label var salesweek "Sales in last week"
* truncate at 99th percentile, as per pre-analysis plan
sum salesweek if round==3, de
replace salesweek=r(p99) if salesweek>r(p99) & salesweek~=. & round==3


***** Sales in the last week of product accounting for largest share of profits
*** Note relatively high item non-response on this question
* Round 2
gen salesmainprod=sec5_11d*sec5_11e
replace salesmainprod=. if sec5_11e==-999|sec5_11e==-888|sec5_11e==-777|sec5_11e==-555|sec5_11d==-999|sec5_11e==-888|sec5_11e==-777|sec5_11e==-555|sec5_11e==.999
replace salesmainprod=0 if sec5_11e==-444|sec5_11d==-444
replace salesmainprod=. if sec5_11e>0.9 & sec5_11e<1
replace salesmainprod=. if salesmainprod<0
* sales are then zero for firms which don't survive
replace salesmainprod=0 if survives==0
label var salesmainprod "Sales in last week from main product, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum salesmainprod, de
replace salesmainprod=r(p99) if salesmainprod>r(p99) & salesmainprod~=.
* Round 3
replace salesmainprod=ss_sec5_11d*ss_sec5_11e if round==3
replace salesmainprod=. if (ss_sec5_11e==-999|ss_sec5_11e==-888|ss_sec5_11e==-777|ss_sec5_11e==-555|ss_sec5_11d==-999|ss_sec5_11e==-888|ss_sec5_11e==-777|ss_sec5_11e==-555) & round==3
replace salesmainprod=0 if (ss_sec5_11e==-444|ss_sec5_11d==-444) & round==3
replace salesmainprod=. if salesmainprod<0 & round==3
* sales are then zero for firms which don't survive
replace salesmainprod=0 if survives==0 
label var salesmainprod "Sales in last week from main product"
* truncate at 99th percentile, as per pre-analysis plan
sum salesmainprod if round==3, de
replace salesmainprod=r(p99) if salesmainprod>r(p99) & salesmainprod~=. & round==3

*** Profits
* Round 2
*** Average weekly profits over last 2 weeks
gen prof1=sec5_9_
replace prof1=. if prof1==-999|prof1==-888|prof1==-555|(prof1>0.8 & prof1<1)
replace prof1=0 if prof1==-444|(prof1>0.4 & prof1<0.5)
replace prof1=250 if prof1==. & sec5_9a==1
replace prof1=750 if prof1==. & sec5_9a==2
replace prof1=1250 if prof1==. & sec5_9a==3
replace prof1=1750 if prof1==. & sec5_9a==4
replace prof1=2250 if prof1==. & sec5_9a==5
replace prof1=2750 if prof1==. & sec5_9a==6
replace prof1=3500 if prof1==. & sec5_9a==7
replace prof1=4500 if prof1==. & sec5_9a==8
replace prof1=6000 if prof1==. & sec5_9a==9
replace prof1=8500 if prof1==. & sec5_9a==10
replace prof1=12500 if prof1==. & sec5_9a==11
sum prof1 if prof1>=15000 & prof1~=., de
replace prof1=r(p50) if prof1==. & sec5_9a==12
replace prof1=0 if survives==0
gen prof2=sec5_9b
replace prof2=. if prof2==-999|prof2==-888|prof2==-555|(prof2>0.8 & prof2<1)
replace prof2=0 if prof2==-444|(prof2>0.4 & prof2<0.5)
replace prof2=250 if prof2==. & sec5_9bi==1
replace prof2=750 if prof2==. & sec5_9bi==2
replace prof2=1250 if prof2==. & sec5_9bi==3
replace prof2=1750 if prof2==. & sec5_9bi==4
replace prof2=2250 if prof2==. & sec5_9bi==5
replace prof2=2750 if prof2==. & sec5_9bi==6
replace prof2=3500 if prof2==. & sec5_9bi==7
replace prof2=4500 if prof2==. & sec5_9bi==8
replace prof2=6000 if prof2==. & sec5_9bi==9
replace prof2=8500 if prof2==. & sec5_9bi==10
replace prof2=12500 if prof2==. & sec5_9bi==11
sum prof2 if prof2>=15000 & prof2~=., de
replace prof2=r(p50) if prof2==. & sec5_9bi==12
replace prof2=0 if survives==0

gen profitsweek=(prof1 + prof2)/2 if prof1~=. & prof2~=.
replace profitsweek=prof1 if prof2==.
replace profitsweek=prof2 if prof1==.
sum profitsweek, de
replace profitsweek=r(p99) if profitsweek>r(p99) & profitsweek~=.
label var profitsweek "Average weekly profits over last 2 weeks, first follow-up"
* round 3
replace prof1=ss_sec5_9_ if round==3
replace prof1=. if (prof1==-999|prof1==-888|prof1==-555) & round==3
replace prof1=0 if prof1==-444 & round==3
replace prof1=250 if prof1==. & ss_sec5_9a==1 & round==3
replace prof1=750 if prof1==. & ss_sec5_9a==2 & round==3
replace prof1=1250 if prof1==. & ss_sec5_9a==3 & round==3
replace prof1=1750 if prof1==. & ss_sec5_9a==4 & round==3
replace prof1=2250 if prof1==. & ss_sec5_9a==5 & round==3
replace prof1=2750 if prof1==. & ss_sec5_9a==6 & round==3
replace prof1=3500 if prof1==. & ss_sec5_9a==7 & round==3
replace prof1=4500 if prof1==. & ss_sec5_9a==8 & round==3
replace prof1=6000 if prof1==. & ss_sec5_9a==9 & round==3
replace prof1=8500 if prof1==. & ss_sec5_9a==10 & round==3
replace prof1=12500 if prof1==. & ss_sec5_9a==11 & round==3
sum prof1 if prof1>=15000 & prof1~=. & round==3, de
replace prof1=r(p50) if prof1==. & ss_sec5_9a==12 & round==3
replace prof1=0 if survives==0 
replace profitsweek=prof1 if round==3
sum profitsweek if round==3, de
replace profitsweek=r(p99) if profitsweek>r(p99) & profitsweek~=. & round==3
label var profitsweek "Weekly profits"


**** Mark-up profits in last week of main product (again high item non-response issues)
* Round 2
gen profmainprod=(sec5_11d-sec5_11c)*sec5_11e
replace profmainprod=. if sec5_11e==-999|sec5_11e==-888|sec5_11e==-777|sec5_11e==-555|sec5_11d==-999|sec5_11e==-888|sec5_11e==-777|sec5_11e==-555
replace profmainprod=. if sec5_11c==-999|sec5_11c==-888|sec5_11c==-777|sec5_11c==-555
replace profmainprod=0 if sec5_11e==-444|sec5_11d==-444|sec5_11c==-444
replace profmainprod=. if sec5_11e>0.9 & sec5_11e<1

* profits are then zero for firms which don't survive
replace profmainprod=0 if survives==0
label var profmainprod "Profits in last week from main product, first follow-up"
* truncate at 99th percentile, as per pre-analysis plan
sum profmainprod, de
replace profmainprod=r(p99) if profmainprod>r(p99) & profmainprod~=.
* also truncate at bottom to remove influence of a few huge negative outliers
replace profmainprod=0 if profmainprod<0
* Round 3
**** Mark-up profits in last week of main product
replace profmainprod=(ss_sec5_11d-ss_sec5_11c)*ss_sec5_11e if round==3
replace profmainprod=. if (ss_sec5_11e==-999|ss_sec5_11e==-888|ss_sec5_11e==-777|ss_sec5_11e==-555|ss_sec5_11d==-999|ss_sec5_11e==-888|ss_sec5_11e==-777|ss_sec5_11e==-555) & round==3
replace profmainprod=. if (ss_sec5_11c==-999|ss_sec5_11c==-888|ss_sec5_11c==-777|ss_sec5_11c==-555) & round==3
replace profmainprod=0 if (ss_sec5_11e==-444|ss_sec5_11d==-444|ss_sec5_11c==-444) & round==3
* profits are then zero for firms which don't survive
replace profmainprod=0 if survives==0
label var profmainprod "Profits in last week from main product"
* truncate at 99th percentile, as per pre-analysis plan
sum profmainprod if round==3, de
replace profmainprod=r(p99) if profmainprod>r(p99) & profmainprod~=. & round==3
* also truncate at bottom to remove influence of a few huge negative outliers
replace profmainprod=0 if profmainprod<0

*** Value of business inventories for sale, truncated at the 99th percentile
gen photoinventories=(TOTAL_GOODSSERVICES_1+TOTAL_GOODSSERVICES_2)/2
replace photoinventories=. if round==3
* replace cases where no photo taken as missing
replace photoinventories=. if round==2 & photoinventories==0 & (Status==4|Status==0)
replace photoinventories=0 if survives==0
sum photoinventories if round==2, de
replace photoinventories=r(p99) if photoinventories>r(p99) & round==2 & photoinventories~=.
* Baseline photoinventories
gen r1_photoinventories=(bl_total_goodsservices1+bl_total_goodsservices)/2
replace r1_photoinventories=. if r1_photoinventories==0 & (Status==0|Status==3)
sum r1_photoinventories if round==2, de
replace r1_photoinventories=r(p99) if r1_photoinventories>r(p99)  & r1_photoinventories~=.
gen r1_photo_miss=r1_photoinventories==.
replace r1_photoinventories=0 if r1_photo_miss==1 & round==2

* Alternative definition
gen photoinv2=(TOTAL_INVENTORY_1+TOTAL_INVENTORY_2)/2
replace photoinv2=. if round==3
replace photoinv2=. if photoinventories==.
replace photoinv2=0 if survives==0
sum photoinv2 if round==2, de
replace photoinv2=r(p99) if photoinv2>r(p99) & round==2 & photoinv2~=.
gen r1_photoinv2=(bl_total_inventory1+ bl_total_inventory2)/2
replace r1_photoinv2=. if r1_photoinv2==0 & (Status==0|Status==3)
sum r1_photoinv2 if round==2, de
replace r1_photoinv2=r(p99) if r1_photoinv2>r(p99) & r1_photoinv2~=.
gen r1_photoinv2_miss=r1_photoinv2==.
replace r1_photoinv2=0 if r1_photoinv2_miss==1 & round==2

*** Photo shows business is bigger
gen biggerbus=Analysis==1
replace biggerbus=. if Analysis==.|Analysis==0

****** Profits and Sales Index
*** Note this is missing if salesweek and profitsweek variables are missing, but otherwise is average of whatever variables are not missing
	foreach var of varlist salesday salesweek salesmainprod profitsweek profmainprod photoinventories { 
		sum `var' if r1_treatedmarket==0
		local thismean = r(mean) 
		local thissd = r(sd) 
		di "`thismean'" 
		di "`thissd'" 
		cap drop z1_`var'
		gen z1_`var' = (`var'-`thismean')/(`thissd') 
	} 
	egen profsalesindex = rowmean(z1_salesday z1_salesweek z1_salesmainprod z1_profitsweek z1_profmainprod z1_photoinventories) 
	label var profsalesindex "Aggregate Index of Profits and Sales Outcomes"
    replace profsalesindex=. if salesweek==. & profitsweek==.

*** Baseline profits and sales index
	foreach var of varlist r1_salesday r1_salesweek r1_salesmainprod r1_profitsweek r1_profmainprod r1_photoinventories { 
		sum `var' if r1_treatedmarket==0
		local thismean = r(mean) 
		local thissd = r(sd) 
		di "`thismean'" 
		di "`thissd'" 
		cap drop z1_`var'
		gen z1_`var' = (`var'-`thismean')/(`thissd') 
	} 
	egen r1_profsalesindex = rowmean(z1_r1_salesday z1_r1_salesweek z1_r1_salesmainprod z1_r1_profitsweek z1_r1_profmainprod z1_r1_photoinventories) 
	label var r1_profsalesindex "Baseline Aggregate Index of Profits and Sales Outcomes"

*** Inverse hyperbolic since transform
gen invsales=ln(salesweek+(((salesweek^2)+1)^(1/2)))
gen invprofits=ln(profitsweek+(((profitsweek^2)+1)^(1/2)))
gen r1_invsales=ln(r1_salesweek+(((r1_salesweek^2)+1)^(1/2)))
gen r1_invprofits=ln(r1_profitsweek+(((r1_profitsweek^2)+1)^(1/2)))

	
*** Reporting Errors
* Round 2
gen error1=salesmainprod>salesweek
replace error1=0 if salesmainprod==.
gen error2=profmainprod>profitsweek
replace error2=0 if profmainprod==.
gen profworstweek=sec5_10_
replace profworstweek=. if sec5_10_==-999|sec5_10_==-888|sec5_10_==-777|sec5_10_==-555
replace profworstweek=0 if sec5_10_==-444
gen error3=profworstweek>profitsweek
replace error3=0 if profworstweek==.
gen error4=profitsweek>salesweek
replace error4=0 if profitsweek==.
gen error5=salesday>salesweek
replace error5=0 if salesday==.
gen error6=sec5_11d<sec5_11c
replace error6=0 if sec5_11d<0|sec5_11c<0|sec5_11c==.
* Round 3
replace profworstweek=ss_sec5_10_ if round==3
replace profworstweek=. if (ss_sec5_10_==-999|ss_sec5_10_==-888|ss_sec5_10_==-777|ss_sec5_10_==-555) & round==3
replace profworstweek=0 if ss_sec5_10_==-444 & round==3
replace error3=profworstweek>profitsweek & round==3
replace error3=0 if profworstweek==. & round==3
replace error6=ss_sec5_11d<ss_sec5_11c if round==3
replace error6=0 if (ss_sec5_11d<0|ss_sec5_11c<0|ss_sec5_11c==.) & round==3
egen totalerrors=rsum(error1 error2 error3 error4 error5 error6)
replace totalerrors=. if survives==0|survives==.
replace totalerrors=. if error1==. & error2==.

*** Hypothesis B1 variables
* B1: Employed for pay
gen employedforpay=survives==1
replace employedforpay=. if survives==.
replace employedforpay=1 if sec3_9_~=""
replace employedforpay=1 if ss_sec3_8_==1 & round==3
label var employedforpay "Employed for pay"
* note no baseline control here since everyone operating a business at baseline
*B1 : Income from work
gen incomefromwork=profitsweek
replace incomefromwork=ss_sec3_13_ if round==3 & ss_sec3_13_>=0 & ss_sec3_13_~=.
replace incomefromwork=sec3_13 if round==2 & sec3_13>=0 & sec3_13~=.
replace incomefromwork=incomefromwork+sec5_21 if sec5_21>0 & round==2 & sec5_21~=.
replace incomefromwork=incomefromwork+sec5_23b if sec5_23b>0 & round==2 & sec5_23b~=.
label var incomefromwork "Income from all work"
* B2 empowerment
* Baseline measure
* Baseline
gen b_empower1=b_s11_1_1==2
replace b_empower1=. if b_s11_1_1==.|b_s11_1_1==888
gen b_empower2=b_s11_2==1
replace b_empower2=. if b_s11_2==.
gen b_empower3=b_s11_4==1
replace b_empower3=. if b_s11_4==.|b_s11_4==888
gen b_empower4=b_s11_7a_1<=2
replace b_empower4=. if b_s11_7a_1==.
gen b_empower5=b_s11_7a_2<=2
replace b_empower5=. if b_s11_7a_2==.
gen b_empower6=b_s11_7a_3<=2
replace b_empower6=. if b_s11_7a_3==.
gen b_empower7=b_s11_7a_4<=2
replace b_empower7=. if b_s11_7a_4==.
gen b_empower8=b_s11_7a_5<=2
replace b_empower8=. if b_s11_7a_5==.
gen b_empower9=b_s11_7a_6<=2
replace b_empower9=. if b_s11_7a_6==.
gen b_empower10=b_s11_7a_9<=2
replace b_empower10=. if b_s11_7a_9==.
egen b_empowerment=rsum(b_empower1-b_empower10)
replace b_empowerment=. if b_empower1==. & b_empower2==.
gen b_empower_miss=b_empowerment==.
replace b_empowerment=0 if b_empower_miss==1

* Long follow-up
gen empower1=cond(sec10_1_==2, 1, 0) if round==2 & sec10_1_~=.
gen empower2=cond(sec9_1_==1,1,0) if round==2 & sec9_1_~=.
gen empower3=cond(sec10_2_==1,1,0) if round==2 & sec10_2_~=.
gen empower4=cond(sec10_3a1<=2,1,0) if round==2 & sec10_3a1<=3
gen empower5=cond(sec10_3a2<=2,1,0) if round==2 & sec10_3a2<=3
gen empower6=cond(sec10_3a3<=2,1,0) if round==2 & sec10_3a3<=3
gen empower7=cond(sec10_3a4<=2,1,0) if round==2 & sec10_3a4<=3
gen empower8=cond(sec10_3a5<=2,1,0) if round==2 & sec10_3a5<=3
gen empower9=cond(sec10_3a6<=2,1,0) if round==2 & sec10_3a6<=3
gen empower10=cond(sec10_3a7<=2,1,0) if round==2 & sec10_3a7<=3
egen empowerment=rsum(empower1-empower10) if round==2
replace empowerment=. if empower1==. & empower2==.
label var empowerment "Empowerment index (higher is more empowered)"

* B3: Subjective well-being
gen laddertoday=sec1_4
replace laddertoday=ss_sec1_4_ if round==3 & ss_sec1_4_>0
label var laddertoday "Ladder of life today"
gen ladder5years=sec1_5
replace ladder5years=ss_sec1_5_ if round==3 & ss_sec1_5_>0
label var ladder5years "Ladder of life in 5 years"
* MHI-5 - code so higher score is better mental health
gen mhi5=(6-sec1_7a)+(6-sec1_7b)+sec1_7c+sec1_7d+sec1_7e

* B4: Household Durable Asset Ownership
* Round 2
gen asset1=cond(sec10_4a==1,1,0) if sec10_4a<=2
gen asset2=cond(sec10_4b==1,1,0) if sec10_4b<=2
gen asset3=cond(sec10_4c==1,1,0) if sec10_4c<=2
gen asset4=cond(sec10_4d==1,1,0) if sec10_4d<=2
gen asset5=cond(sec10_4e==1,1,0) if sec10_4e<=2
gen asset6=cond(sec10_4f==1,1,0) if sec10_4f<=2
gen asset7=cond(sec10_4g==1,1,0) if sec10_4g<=2
gen asset8=cond(sec10_4h==1,1,0) if sec10_4h<=2
gen asset9=cond(sec10_4i==1,1,0) if sec10_4i<=2
gen asset10=cond(sec10_4j==1,1,0) if sec10_4j<=2
gen asset11=sec10_4k if sec10_4k>=0
gen asset12=sec10_4l if sec10_4l>=0
pca asset1-asset12 if round==2
predict assetindex if round==2
label var assetindex "Household Durable Assets Index"
* Baseline
pca b_s10_3_iron_heaters-b_s10_3_gascookers if round==2
predict b_assetindex if round==2
label var b_assetindex "Baseline Asset Index"

*** C2: Market-Level Averages
egen marketsales=mean(salesweek), by(market1 round)
egen marketprof=mean(profitsweek), by(market1 round)


*** D1: Business Knowledge and Practices
*** Business Knowledge
gen know1=sec10_5a==10000
replace know1=. if sec10_5a==.
gen know2=sec10_5b==10000
replace know2=. if sec10_5a==.
* allow for cash or accrual-based accounting
gen know3=sec10_5c==10000|sec10_5c==5000
replace know3=. if sec10_5a==.
gen know4=sec10_5d==11000|sec10_5d==6000
replace know4=. if sec10_5a==.
gen know5=sec10_5e==4000|sec10_5e==-1000
replace know5=. if sec10_5a==.
gen know6=sec10_5f==1000
replace know6=. if sec10_5a==.
gen know7=sec10_5g==9
replace know7=. if sec10_5a==.
egen knowledge=rsum(know1 know2 know3 know4 know5 know6 know7)
label var knowledge "Knowledge test score in first follow-up survey"
replace knowledge=. if sec10_5a==.
replace knowledge=. if round==3
***D2: Business Practices
*** Baseline
foreach x of varlist b_s9_1a-b_s9_4h  b_s9_4i b_s9_5 b_s9_6-b_s9_9 b_s9_10-b_s9_13 b_s9_14-b_s9_22 b_s9_23-b_s9_26 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & b_s9_1a~=.
}
gen b_bp_m1=b_s9_1a
gen b_bp_m2=b_s9_1b
gen b_bp_m3=b_s9_1c
gen b_bp_m4=b_s9_1d
gen b_bp_m5=b_s9_1e
gen b_bp_m6=b_s9_2
gen b_bp_m7=b_s9_3
gen b_bp_b1=b_s9_6
gen b_bp_b2=b_s9_7
gen b_bp_b3=0 if b_s9_10==4
replace b_bp_b3=1 if b_s9_10<=3
replace b_bp_b3=1 if b_s9_8==0
foreach x of varlist b_s9_15-b_s9_17  { 
replace `x' = 0 if b_s9_14==0
}
gen b_bp_r1=b_s9_14
gen b_bp_r2=b_s9_15
gen b_bp_r3=b_s9_16
gen b_bp_r4=b_s9_17
gen b_bp_r5=b_s9_18
gen b_bp_r6=b_s9_19
gen b_bp_r7=b_s9_20
gen b_bp_r8=b_s9_22 
gen b_bp_f1=b_s9_23==4
replace b_s9_24=1 if b_s9_24==3|b_s9_24==4
gen b_bp_f2=b_s9_24
gen b_bp_f3=1 if b_s9_24a==4
replace b_bp_f3=0 if b_s9_24a<=3|b_s9_24==0
gen b_bp_f4=b_s9_25

egen b_totalscore=rmean(b_bp_m1-b_bp_f4)
label var b_totalscore "BaselineBusiness Practices Score"
gen b_totalscore_miss=b_totalscore==.
replace b_totalscore=0 if b_totalscore_miss==1

* Round 2
foreach x of varlist sec7_1a-sec7_4h sec7_14-sec7_20 sec7_22 sec7_6_ sec7_7 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & sec7_1a~=.
}
gen bp_m1=sec7_1a
replace bp_m1=0 if sec7_1a==3
gen bp_m2=sec7_1b
replace bp_m2=0 if sec7_1b==3
gen bp_m3=sec7_1c
replace bp_m3=. if sec7_1c==3
gen bp_m4=sec7_1d
replace bp_m4=0 if sec7_1d==3
replace bp_m4=. if sec7_1d==4
gen bp_m5=sec7_1e
replace bp_m5=0 if sec7_1e==3
replace bp_m5=. if sec7_1e==4
gen bp_m6=sec7_2_ if sec7_2_<=1
gen bp_m7=sec7_3_ if sec7_3_<=1

gen bp_b1=sec7_6_ if sec7_6_<=1
gen bp_b2=sec7_7_ if sec7_7_<=1
gen bp_b3=0 if sec7_10_==4
replace bp_b3=1 if sec7_10_<=3
replace bp_b3=1 if sec7_8_==0

foreach x of varlist sec7_15_-sec7_17_  { 
replace `x' = 0 if sec7_14_==0
}
foreach x of varlist sec7_14_-sec7_22_  { 
replace `x' = . if `x'>1
}
gen bp_r1=sec7_14_
gen bp_r2=sec7_15_
gen bp_r3=sec7_16_
gen bp_r4=sec7_17_
gen bp_r5=sec7_18_
gen bp_r6=sec7_19_
gen bp_r7=sec7_20_
gen bp_r8=sec7_22_ 
gen bp_f1=sec7_23_==4
replace bp_f1=. if sec7_23_==.
gen bp_f2=1 if sec7_24_ ==1
replace bp_f2=0 if sec7_24_==2
gen bp_f3=1 if sec7_24a==4
replace bp_f3=0 if sec7_24a<=3|bp_f2==0
replace sec7_25_=0 if sec7_25_==2
gen bp_f4=sec7_25_ if sec7_25<=1 

foreach x of varlist sec7_26_1-sec7_26_4  { 
replace `x' = 0 if sec7_26_5==1|(`x'==. & bp_r1~=.)|(`x'>1 & bp_r1~=.)
replace `x' = . if bp_f4==. & bp_m1==. & bp_m2==.
}
gen bp_f5=sec7_26_1
gen bp_f6=sec7_26_2
gen bp_f7=sec7_26_3
gen bp_f8=sec7_26_4

egen marketingscore=rmean(bp_m1 bp_m2 bp_m3 bp_m4 bp_m5 bp_m6 bp_m7)
label var marketingscore "Proportion of marketing practices used"
egen stockscore=rmean(bp_b1 bp_b2 bp_b3)
label var stockscore "Proportion of buying and stock control practices used"
egen recordscore=rmean(bp_r1 bp_r2 bp_r3 bp_r4 bp_r5 bp_r6 bp_r7 bp_r8)
label var recordscore "Proportion of record-keeping practices used"
egen planningscore=rmean(bp_f1-bp_f8)
label var planningscore "Proportion of financial planning practices used"
egen totalscore=rmean(bp_m1-bp_f8)
label var totalscore "Business Practices Score"
*** D2 - customer acquisition, and gaining and losing customers
* Round 2 - number of customers
gen numcustomers=sec5_14_
replace numcustomers=. if sec5_14_<0
replace numcustomers=2.5 if numcustomers==. & sec5_14a==1
replace numcustomers=7.5 if numcustomers==. & sec5_14a==2
replace numcustomers=15 if numcustomers==. & sec5_14a==3
replace numcustomers=25 if numcustomers==. & sec5_14a==4
replace numcustomers=35 if numcustomers==. & sec5_14a==5
replace numcustomers=45 if numcustomers==. & sec5_14a==6
replace numcustomers=62.5 if numcustomers==. & sec5_14a==7
replace numcustomers=87.5 if numcustomers==. & sec5_14a==8
replace numcustomers=150 if numcustomers==. & sec5_14a==9
replace numcustomers=250 if numcustomers==. & sec5_14a==10
sum numcustomers if numcustomers>300 & numcustomers~=., de
replace numcustomers=r(p50) if numcustomers==. & sec5_14a==11
* customers are zero for those not in business
replace numcustomers=0 if survive==0
* truncate at 99th percentile
sum numcustomers if round==2, de
replace numcustomers=r(p99) if numcustomers>r(p99) & numcustomers~=.
label var numcustomers "Number of customers in the past week"
* Round 3 number of customers
replace numcustomers=ss_sec5_14_ if ss_sec5_14_>0 & round==3 & ss_sec5_14_~=.
replace numcustomers=2.5 if numcustomers==. & ss_sec5_14a==1 & round==3
replace numcustomers=7.5 if numcustomers==. & ss_sec5_14a==2 & round==3
replace numcustomers=15 if numcustomers==. & ss_sec5_14a==3 & round==3
replace numcustomers=25 if numcustomers==. & ss_sec5_14a==4 & round==3
replace numcustomers=35 if numcustomers==. & ss_sec5_14a==5 & round==3
replace numcustomers=45 if numcustomers==. & ss_sec5_14a==6 & round==3
replace numcustomers=62.5 if numcustomers==. & ss_sec5_14a==7 & round==3
replace numcustomers=87.5 if numcustomers==. & ss_sec5_14a==8 & round==3
replace numcustomers=150 if numcustomers==. & ss_sec5_14a==9 & round==3
replace numcustomers=250 if numcustomers==. & ss_sec5_14a==10 & round==3
sum numcustomers if numcustomers>300 & numcustomers~=. & round==3, de
replace numcustomers=r(p50) if numcustomers==. & ss_sec5_14a==11 & round==3
replace numcustomers=0 if survive==0
* truncate at 99th percentile
sum numcustomers if round==3, de
replace numcustomers=r(p99) if numcustomers>r(p99) & numcustomers~=. & round==3

* Gained a Customer
gen gainednewcustomer=sec5_15==1
replace gainednewcustomer=. if sec5_15==.
replace gainednewcustomer=0 if survives==0
label var gainednewcustomer "Gained new customer in past 3 months"
replace gainednewcustomer=ss_sec5_15_==1 if round==3
replace gainednewcustomer=. if (ss_sec5_15_==. & round==3)
replace gainednewcustomer=0 if survives==0 & round==3
* Lost a customer
gen lostcustomer=sec5_16==1
replace lostcustomer=. if sec5_16==.
replace lostcustomer=1 if survives==0
label var lostcustomer "Lost a regular customer in past 3 months"
replace lostcustomer=ss_sec5_16==1 if round==3
replace lostcustomer=. if ss_sec5_16==. & round==3
replace lostcustomer=1 if survives==0 & round==3

*** D3: reacting to down times
* Ratio of worst week profits to current week
gen ratioprof=profworstweek/profitsweek
sum ratioprof, de
replace ratioprof=r(p1) if ratioprof<r(p1)
replace ratioprof=r(p99) if ratioprof>r(p99) & ratioprof~=.
label var ratioprof "Ratio of worst to current week profits"
* Monitor records to see if sales increasing or decreasing for a particular product
gen monitorrecs=sec7_17_==1
replace monitorrecs=. if sec7_17_==.
replace monitorrecs=0 if survives==0
label var monitorrecs "Uses records to see if sales increasing or decreasing"
gen b_monitorrecs=b_bp_r4
gen b_monitorrecs_miss=b_monitorrecs==.
replace b_monitorrecs=0 if b_monitorrecs_miss==1

*** D4 accessing financing and building up inventories and capital
gen receivedloan=sec4_11a1==1|sec4_11a2==1
replace receivedloan=. if sec4_10_==.
label var receivedloan "Received loan from bank or microfinance"
gen b_receivedloan=b_s4_4a_1==1|b_s4_4a_2==1|b_s4_4a_3==1
replace b_receivedloan=. if b_s4_4a_1==.
gen b_receivedloan_miss=b_receivedloan==.
replace b_receivedloan=0 if b_receivedloan_miss==1
label var b_receivedloan "Baseline receipt of loan from bank or microfinance"

gen inventories=sec5_4_
replace inventories=. if inventories<0
replace inventories=0 if sec5_3_==2
replace inventories=0 if survives==0
sum inventories if round==2, de
replace inventories=r(p99) if inventories>r(p99) & inventories~=.
label var inventories "Value of inventories in first follow-up"
gen b_inventories=b_s5_3
replace b_inventories=. if b_s5_3==999
replace b_inventories=0 if b_s5_2==2
gen b_inventories_miss=b_inventories==.
replace b_inventories=0 if b_inventories_miss==1
label var b_inventories "Baseline value of inventories"

*** Difference between photo value of inventories and actual
gen inventdiff=inventories-photoinventories

foreach var of varlist sec5_2a1 sec5_2a2 sec5_2a3 sec5_2a4 {
replace `var'=. if `var'<0
}
gen ownedcapital=sec5_2a1+sec5_2a2+sec5_2a3+sec5_2a4 
replace ownedcapital=0 if survives==0
sum ownedcapital if round==2, de
replace ownedcapital=r(p99) if ownedcapital>r(p99) & ownedcapital~=.
label var ownedcapital "Value of capital"
foreach var of varlist b_s5_1a_1 b_s5_1a_2 b_s5_1a_3 b_s5_1a_4 {
replace `var'=. if `var'<0
}
gen b_ownedcapital=b_s5_1a_1+b_s5_1a_2+b_s5_1a_3+b_s5_1a_4
sum b_ownedcapital if round==2, de
replace b_ownedcapital=r(p99) if b_ownedcapital>r(p99) & b_ownedcapital~=. & round==2
gen b_ownedcapital_miss=b_ownedcapital==.
replace b_ownedcapital=0 if b_ownedcapital_miss==1

*** D5: inventory losses and stock management
gen fractionstocklost=sec5_4a/inventories
replace fractionstocklost=. if sec5_4a<0
sum fractionstocklost if round==2, de
replace fractionstocklost=r(p99) if fractionstocklost>r(p99) & fractionstocklost~=.
label var fractionstocklost "Fraction of stock lost to spoilage"

gen bulkdiscount=sec5_4b==1
replace bulkdiscount=. if sec5_4b==.
replace bulkdiscount=0 if survives==0
label var bulkdiscount "Received bulk discount when purchasing materials"

gen prodcostchange=100*(sec5_11c-r1_costmainproduct)/r1_costmainproduct
replace prodcostchange=. if sec5_11c<0
sum prodcostchange if round==2, de
replace prodcostchange=r(p5) if prodcostchange<r(p5) 
replace prodcostchange=r(p95) if prodcostchange>r(p95) & prodcostchange~=.
label var prodcostchange "Production cost change"

*** D6: hours worked, self-efficacy, and attitudes
gen laborhours=sec4_1a
replace laborhours=0 if laborhours==-444
replace laborhours=0 if survives==0
sum laborhours if round==2, de
replace laborhours=r(p99) if laborhours>r(p99) & laborhours~=.
label var laborhours "Labor hours in last week"
gen b_laborhours=b_s1_5_a
replace b_laborhours=. if b_s1_5_a==888
sum b_laborhours, de
replace b_laborhours=r(p99) if b_laborhours>r(p99) & b_laborhours~=.
gen b_laborhours_miss=b_laborhours==.
replace b_laborhours=0 if b_laborhours_miss==1
label var b_laborhours "Baseline weekly labor hours"

gen selfeff1=sec1_6a==4
gen selfeff2=sec1_6b==4
gen selfeff3=sec1_6c==4
gen selfeff4=sec1_6d==4
gen selfeff5=sec1_6e==4
gen selfeff6=sec1_6f==4
gen selfeff7=sec1_6g==4
gen selfeff8=sec1_6h==4
gen selfeff9=sec1_6i==4
gen selfeff10=sec1_6j==4
egen selfefficacy=rsum(selfeff1-selfeff10)
replace selfefficacy=. if sec1_6a==.
label var selfefficacy "Entrepreneurial Self-efficacy"

gen attitude1=sec1_8a
gen attitude2=sec1_8b
gen attitude3=6-sec1_8c
gen attitude4=6-sec1_8d
gen attitude5=sec1_8e
gen attitude6=6-sec1_8f
gen attitude7=sec1_8g
gen attitude8=sec1_8h
gen attitude9=sec1_8i
gen attitude10=6-sec1_8j
gen attitude11=sec1_8k
egen GETattitude=rowmean(attitude1-attitude11)
label var GETattitude "GET Ahead Attitudes"
foreach var of varlist b_s3_9a-b_s3_9k {
replace `var'=. if `var'>5
}
gen b_attitude1=b_s3_9a
gen b_attitude2=b_s3_9b
gen b_attitude3=6-b_s3_9c
gen b_attitude4=6-b_s3_9d
gen b_attitude5=b_s3_9e
gen b_attitude6=6-b_s3_9f
gen b_attitude7=b_s3_9g
gen b_attitude8=b_s3_9h
gen b_attitude9=b_s3_9i
gen b_attitude10=6-b_s3_9j
gen b_attitude11=b_s3_9k
egen b_GETattitude=rowmean(b_attitude1-b_attitude11)
label var b_GETattitude "Baseline GET Ahead Attitudes"
gen b_GETattitude_miss=b_GETattitude==.
replace b_GETattitude=0 if b_GETattitude_miss==1

*** D7: networking and working together
gen belongwomenassoc=cond(sec6_1a2==1,1,0) if sec6_1a2<=2
label var belongwomenassoc "Belong to a women's association"
gen discussbusiness=sec_6_2_ if sec_6_2_>=0
sum discussbusiness if round==2, de
replace discussbusiness=r(p99) if discussbusiness>=r(p99) & discussbusiness~=.
label var discussbusiness "Number of other women they discuss business with"
gen worktogether=cond(sec_6_3_==1, 1, 0) if sec_6_3_<=2
label var worktogether "Works together with other women to get discount or buy materials"

** outcome suggested by qualitative work: membership of Roscas/Merry-go-rounds
cap drop belongmerrygo
gen belongmerrygo=cond(sec6_1a1==1,1,0) if sec6_1a1<=2
label var belongmerrygo "Belong to a merry-go-round"
gen b_belongmerrygo=q18_merry_go_round_member==1
label var b_belongmerrygo "Belong to merry go round at baseline"

*** Indicators of innovation and change in activity
gen changedactivity=sec2_3_==2
gen introducenewproduct=sec5_12==1 if round==2 & sec5_12_~=.
label var introducenewproduct "Introduced new product"

****** Use of other labor
gen anyotherworker=cond(sec4_4_==1,1,0) if sec4_4_<=2 & round==2
replace anyotherworker=0 if survives==0 & round==2
label var anyotherworker "Anyone else work in business"
gen paidworkers=0 
replace paidworkers=sec4_5b1 if sec4_5f1=="1"|sec4_5f1=="2"
replace paidworkers=paidworkers+sec4_5b2 if sec4_5f2=="1"|sec4_5f2=="2"
replace paidworkers=paidworkers+sec4_5b3 if sec4_5f3=="1"|sec4_5f3=="2"
replace paidworkers=paidworkers+sec4_5b4 if sec4_5f4=="1"|sec4_5f4=="2"
replace paidworkers=paidworkers+sec4_5b5 if sec4_5f5=="1"|sec4_5f5=="2"
replace paidworkers=paidworkers+sec4_5b6 if sec4_5f6=="1"|sec4_5f6=="2"
replace paidworkers=. if round==3
replace paidworkers=. if round==2 & anyotherworker==.


********************************* append in round 4 *******************
append using "R4R5data.dta"

egen mspillovertreat=max(spillovertreat), by(respid)
replace spillovertreat=mspillovertreat if round==4|round==5
egen mar1_market1=max(r1_market1), by(respid)
replace r1_market1=mar1_market1 if round==4|round==5
egen mar1_Strata=max(r1_Strata), by(respid)
replace r1_Strata=mar1_Strata if round==4|round==5
egen mar1_treated=max(r1_treated), by(respid)
replace r1_treated=mar1_treated if round==4|round==5

* gen indicators of being in mentoring market, being too small for mentoring treatment, etc.
gen smallmkt=nummarket<16 if round==2
egen msmallmkt=max(smallmkt), by(r1_market1)
gen mentormkt=newTreat==1
egen mmentormkt=max(mentormkt), by(r1_market1)
label var mmentormkt "Market assigned to mentoring"
gen r1_mentored=r1_treated if mmentormkt==1
replace r1_mentored=0 if r1_mentored==.
gen r1_mentor_spill=spillovertreat if mmentormkt==1
replace r1_mentor_spill=0 if r1_mentor_spill==.
gen r1_trainonly=r1_treated if mmentormkt==0
replace r1_trainonly=0 if r1_trainonly==.
gen r1_trainonly_spill=spillovertreat if mmentormkt==0
replace r1_trainonly_spill=0 if r1_trainonly_spill==.

save "FullCombinedData.dta", replace


*********** 2017 data ***********

use "2017data/Female&MaleVendorSurveys_appended_publicuse.dta", clear

gen respid=respoid
sort respid
merge respid using "2017data/mentorstatus.dta"
rename _merge _merment
sort respid
merge respid using "2017data/indtreatstatus.dta"

* Clean the other business type
#delimit ;
replace q5_biztype=10 if q5_biztypeother=="AGROVET"|q5_biztypeother=="Agrovet";
replace q5_biztype=14 if q5_biztypeother=="BAR"|q5_biztypeother=="Bar";
replace q5_biztype=6 if q5_biztypeother=="BARBER"|q5_biztypeother=="BARBER KINYOZI"|q5_biztypeother=="BARBER SHOP"|
q5_biztypeother=="BARBERSHOP"|q5_biztypeother=="Barber"|q5_biztypeother=="Baber shop"|q5_biztypeother=="Barber Shop"|
q5_biztypeother=="Barber shop"|q5_biztypeother=="Barbershop"|q5_biztypeother=="Kinyozi"|q5_biztypeother=="KINYOZI";
replace q5_biztype=15 if q5_biztypeother=="Battery charging";
replace q5_biztype=8 if q5_biztypeother=="Boutique"|q5_biztypeother=="Boutique & Textiles"|q5_biztypeother=="Clothes"|q5_biztypeother=="MITUMBA CLOTHES";
replace q5_biztype=2 if q5_biztypeother=="Cereal shop"|q5_biztypeother=="Cereals";
replace q5_biztype=1 if q5_biztypeother=="Cereals  and vegetables"|q5_biztypeother=="Fruits"|q5_biztypeother=="Irish Potatoes"|q5_biztypeother=="MPESA AND FRUITS/VEGETABLES";
replace q5_biztype=19 if q5_biztypeother=="Computer services";
replace q5_biztype=7 if q5_biztypeother=="Mali mali"|q5_biztypeother=="Malimali"|q5_biztypeother=="Malimali  shop selling jembe, sanduku.."|
q5_biztypeother=="Malimali vender"|q5_biztypeother=="Potatoes seller"|q5_biztypeother=="Roots and sweet potatoe"|q5_biztypeother=="Sale of tomatoes"|q5_biztypeother=="Sweet Potatoes"|
q5_biztypeother=="Tomatoes and potatoes seller"|q5_biztypeother=="Tomatoes seller";
replace q5_biztype=20 if q5_biztypeother=="Charcoal"|q5_biztypeother=="Charcoal dealer";
#delimit cr


* share of men in market in our sectors
gen malesector=1 if q5_biztype==22|q5_biztype==11|q5_biztype==17|q5_biztype==18|q5_biztype==19|q5_biztype==21


gen female=cond(q3_gender==2, 1,0) if q3_gender~=.


* test impact on selling product no one else sells, conditional on operating
gen sellnooneelse=cond(q7_prodnosell==1,1,0) if  q7_prodnosell~=.
gen spillovertreat=treatedmarket==1 & _merge==3 & r1_treated==0
replace spillovertreat=. if _merge~=3

* Get truncated sales
gen sales_trunc=q14_sales
replace sales_trunc=. if sales_trunc<0
sum sales_trunc if _merge==3 & treatedmarket==0, de
replace sales_trunc=r(p99) if _merge==3 & sales_trunc>r(p99) & sales_trunc~=.

* Impact on truncated sales for men
egen mtreatedmarket=max(treatedmarket), by(marketid)
egen mStrata=max(r1_Strata), by(marketid)
sum sales_trunc if q3_gender==1 & mtreatedmarket==0 & _merge~=3, de
replace sales_trunc=r(p99) if q3_gender==1 & _merge~=3 & sales_trunc>r(p99) & sales_trunc~=.

gen logsales=log(sales_trunc)

*** Profits
gen prof_trunc=q16_profit
replace prof_trunc=. if prof_trunc<0
sum prof_trunc if _merge==3 & treatedmarket==0, de
replace prof_trunc=r(p99) if _merge==3 & prof_trunc>r(p99) & prof_trunc~=.

sum prof_trunc if q3_gender==1 & mtreatedmarket==0 & _merge~=3, de
replace prof_trunc=r(p99) if q3_gender==1 & _merge~=3 & prof_trunc>r(p99) & prof_trunc~=.

gen logprof=log(prof_trunc)

*** Interviewed and Operating
gen intoperate=cond(business_operational==1,1,0) if business_operational~=.

save Female&MaleVendorSurveys_combined, replace
