**** File for PLOS One Article


use AllBaselineKenyaPublicUse.dta, clear

**************** Table 1: Random Assignment numbers by treatment type and region *************************
label define RegionLabel 1 "Kakamega"
label define RegionLabel 2 "Kisii", add
label define RegionLabel 3 "Embu", add
label define RegionLabel 4 "Kitui", add
label values region RegionLabel
label define TreatLabel 1 "Standard Invite"
label define TreatLabel 2 "Active Choice", add
label define TreatLabel 3 "Enhanced Active Choice", add
label values treattype TreatLabel
tab region treattype


**************** Table 2: Summary Statistics by Treatment Type ********************************************
*** Construct individual and business characteristics 

**** individual characteristics
gen above35=age>35
label var above35 "Aged above 35"
gen yearsedn=b_s1_16
replace yearsedn=b_s1_17 if b_s1_17~=.
label var yearsedn "Years of Schooling"
gen married=cond(b_s1_18==2,1,0) if b_s1_18~=.
label var married "Married"
gen haschildren=cond(b_s1_21>0 & b_s1_21<20,1,0) if b_s1_21<20
label var haschildren "Has a child"
gen child5under=cond(b_s1_22<=5,1,0) if haschildren~=.
label var child5under "Has a child of 5 and under"
replace b_s1_26c=. if b_s1_26c>20
replace b_s1_26b=. if b_s1_26b>20
gen hhsize=b_s1_26a+b_s1_26b+b_s1_26c
label var hhsize "Household Size"
gen highdiscountrate=b_s4_6<=800
label var highdiscountrate "High discount rate"
gen hyperbolic=b_s4_6<b_s13_2
label var hyperbolic "Hyperbolic discounter"
gen raven=b_s12_1_total_b if b_s12_1_total_b<=12
label var raven "Raven test score"
gen digitspan=3 if b_s13_1_a==2
replace digitspan=4 if b_s13_1_a==1
replace digitspan=5 if b_s13_1_b==1
replace digitspan=6 if b_s13_1_c==1
replace digitspan=7 if b_s13_1_d==1
replace digitspan=8 if b_s13_1_e==1
replace digitspan=9 if b_s13_1_f==1
replace digitspan=10 if b_s13_1_g==1
replace digitspan=11 if b_s13_1_h==1
label var digitspan "Digitspan recall"
gen previoustraining=cond(b_s7_1==1,1,0) if b_s7_1~=.
label var previoustraining "Owner has previously participated in business training"

**** Business characteristics
gen retail=b_business_nature==3
label var retail "Sector is retail"
gen services=b_business_nature==2
label var services "Sector is services"
replace retail=. if b_business_nature==.
replace services=. if b_business_nature==.
gen hoursworked=b_s1_5_a
replace hoursworked=. if b_s1_5_a>168
label var hoursworked "Weekly hours worked by owner in business"
gen ageoffirm=2013-b_s1_10_year
replace ageoffirm=. if b_s1_10_year<1950|b_s1_10_year>2013
label var ageoffirm "Age of firm in years"
gen b_keeprecords=b_s1_11==1
label var b_keeprecords "Keeps business records"
gen nonfamilyinbus=b_s1_13_a_6==1
label var nonfamilyinbus "Has a non-family member employee"
egen nonlandK=rsum(b_s5_1a_1- b_s5_1a_4)
gen inventories=b_s5_3 if b_s5_3~=999
replace inventories=0 if b_s5_2==2
gen totalK=nonlandK+inventories
label var totalK "Capital stock (excluding land and buildings)"

* Management Scores: following coding of de Mel el al. (2013)
foreach x of varlist b_s9_1a-b_s9_4h  b_s9_4i b_s9_5 b_s9_6-b_s9_9 b_s9_10-b_s9_13 b_s9_14-b_s9_22 b_s9_23-b_s9_26 { 
replace `x'=. if `x'>100
replace `x'=0 if `x'==2
replace `x'=0 if `x'==. & b_s9_1a~=.
}
* MARKETING
gen marketingscore=b_s9_1a+b_s9_1b+b_s9_1c+b_s9_1d+b_s9_1e+b_s9_2+b_s9_3
* BUYING AND STOCK CONTROL
gen runoutstockfrequently=b_s9_10==4 
replace runoutstock=runoutstock*-1
gen stockscore=b_s9_6+b_s9_7+runoutstock
* RECORD-KEEPING AND COSTING
egen recordscore=rsum(b_s9_14-b_s9_20 b_s9_22)
* FINANCIAL PLANNING
replace b_s9_23=2 if b_s9_23==0
replace b_s9_23=b_s9_23-1
replace b_s9_24a=2 if b_s9_24a==0
replace b_s9_24a=b_s9_24a-1
replace b_s9_24a=0 if b_s9_24==0
egen planningscore=rsum(b_s9_23-b_s9_25)
* TOTAL
gen totalscore=marketingscore+stockscore+recordscore+planningscore
label var totalscore "Total business practices score"

gen above10k=disttotraining>=10 if disttotraining~=.
label var above10k "Distance to training above 10km"

keep if treattype~=.
 
gen optin=treattype==1

local bus_vars "age above35 yearsedn married haschildren child5under hhsize highdiscount hyperbolic raven digit previoustraining retail service hoursworked ageoffirm  b_keeprecords nonfamilyinbus censusprofits totalK totalscore disttotraining above10k" 

est drop _all

local i=1
foreach x of local bus_vars  {
reg `x' optin activechoice enhancedactive, r noc
eststo means_`i'
areg `x' activechoice enhancedactive, r a(market1)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo means1_`i'
	local i = `i' + 1
}
#delimit ;
esttab means_* means1_* using plostable2.csv, replace legend label nonumbers nostar not
	b(%9.3f) 
	stats(pvalue, fmt(%9.3f) labels("p-value")) 
	title("Balance and Summary Statistics") addnotes("""") ;
#delimit cr
 
 
 ************** Table 3/Figure 1: Results of Invitation Type on Attendance ***************
 * Summarize three attendance measures
 replace sayswillattend=0 if eattend~=. & sayswillattend==.
 label var sayswillattend "Says will attend training"
 label var eattend "Attended at least one day of training"
 
 * public use data didn't distinguish reinvitee attendees.
 cap drop numberdays
 #delimit ;
 gen reinvitee=respondent_id==10820056|respondent_id==10820024 |respondent_id==20050029 |respondent_id==20050010
 |respondent_id== 20080028 |respondent_id== 20160034|respondent_id==20380018  |respondent_id==20460012
 |respondent_id==20570029 |respondent_id==30210012 |respondent_id==30350030 |respondent_id==30350013
 |respondent_id==40030005 |respondent_id==40060012 |respondent_id==40060008 |respondent_id==40610020 ;
 #delimit cr
 gen numberdays=numdaystrained
 replace numberdays=0 if reinvitee==1
 
 sum sayswillattend eattend numberdays
 gen attendsallfive=numberdays==5
 label var attendsallfive "Attends all 5 days of training"
sum attendsallfive if eattend==1, de
gen followsthrough=attendsallfive/sayswillattend
label var followsthrough "Follows through on intention to attend"

*** Treatment impacts
est drop _all
foreach var of var sayswillattend eattend attendsallfive  followsthrough {
xi: reg `var' activechoice enhancedactive i.market1, r
sum `var' if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo table3_`i'
local i = `i' + 1
}


#delimit ;
esttab table3_* using table3.csv, replace depvar legend label nonumbers
	drop(_Imarket* _cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(mean N pvalue, fmt(%9.3f %9.0g) labels("Opt-in Mean" "Sample Size" "p-value")) 
	title("Table 3: Impact of Treatment Type on Attendance") addnotes("""") ;
#delimit cr

*** Appendix 1: Robustness check requested by the referee

* panel B: controlling for previous training attendance
est drop _all
foreach var of var sayswillattend eattend attendsallfive  followsthrough {
xi: reg `var' activechoice enhancedactive i.market1 previoustraining, r
sum `var' if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo table3_`i'
local i = `i' + 1
}


#delimit ;
esttab table3_* using table3b.csv, replace depvar legend label nonumbers
	drop(_Imarket* _cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(mean N pvalue, fmt(%9.3f %9.0g) labels("Opt-in Mean" "Sample Size" "p-value")) 
	title("Table 3: Impact of Treatment Type on Attendance") addnotes("""") ;
#delimit cr


* panel c: controlling for variables significant in table 4
est drop _all
foreach var of var sayswillattend eattend attendsallfive  followsthrough {
xi: reg `var' activechoice enhancedactive i.market1 above35 married hhsize highdiscount above10k censusprofits previoustraining retail , r
sum `var' if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo table3_`i'
local i = `i' + 1
}


#delimit ;
esttab table3_* using table3c.csv, replace depvar legend label nonumbers
	drop(_Imarket* _cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(mean N pvalue, fmt(%9.3f %9.0g) labels("Opt-in Mean" "Sample Size" "p-value")) 
	title("Table 3: Impact of Treatment Type on Attendance") addnotes("""") ;
#delimit cr

***** Table 4: Correlates of Training Attendance
* rescale profits
replace censusprofits=censusprofits/1000
replace totalK=totalK/1000
local bus_vars "above35 yearsedn married haschildren child5under hhsize highdiscount hyperbolic raven digit previoustraining retail  b_keeprecords nonfamilyinbus censusprofits totalK totalscore  above10k" 
dprobit eattend `bus_vars' , r
eststo table4_1
xi: dprobit eattend `bus_vars' i.region, r
eststo table4_2

#delimit ;
esttab table4_1 table4_2 using table4.csv, replace depvar legend label nonumbers
	drop( _cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(N , fmt(%9.3f %9.0g) labels( "Sample Size" )) 
	title("Table 4: Correlates of Attendance in a Probit") addnotes("""") ;
#delimit cr



************ Table 5: Treatment Effects by Sub-Group ************

est drop _all
*** By Age
xi: reg eattend activechoice enhancedactive i.market1 if above35==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_1

xi: reg eattend activechoice enhancedactive i.market1 if above35==0, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_2

* test equality of treatment effects by age
gen activechoice_above35=activechoice*above35
gen enhanced_above35=enhancedactive*above35
xi: reg eattend activechoice enhancedactive activechoice_above35 enhanced_above35 above35 i.market1, r

*** By decision-making power
gen highpower=b_s11_7a_3==1
gen medpower=b_s11_7a_3==2
gen lowpower=b_s11_7a_3==3

xi: reg eattend activechoice enhancedactive i.market1 if highpower==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_3

xi: reg eattend activechoice enhancedactive i.market1 if medpower==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_4

xi: reg eattend activechoice enhancedactive i.market1 if lowpower==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_5

gen activechoice_highpower=activechoice*highpower
gen enhanced_highpower=enhancedactive*highpower
gen activechoice_medpower=activechoice*medpower
gen enhanced_medpower=enhancedactive*medpower
#delimit ;
xi: reg eattend activechoice enhancedactive activechoice_highpower enhanced_highpower
activechoice_medpower enhanced_medpower highpower medpower i.market1, r;
#delimit cr
test activechoice_highpower==activechoice_medpower==0
test enhanced_highpower==enhanced_medpower==0

*** By education level
gen highschool=yearsedn>=12
xi: reg eattend activechoice enhancedactive i.market1 if highschool==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_6

xi: reg eattend activechoice enhancedactive i.market1 if highschool==0, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_7

gen activechoice_highschool=activechoice*highschool
gen enhanced_highschool=enhancedactive*highschool
xi: reg eattend activechoice enhancedactive activechoice_highschool enhanced_highschool highschool i.market1, r


*** by raven score ability
gen highraven=raven>7

xi: reg eattend activechoice enhancedactive i.market1 if highraven==1, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_8

xi: reg eattend activechoice enhancedactive i.market1 if highraven==0, r
sum eattend if optin==1 & e(sample) 
estadd scalar mean = r(mean)
test activechoice==enhancedactive==0
estadd scalar pvalue = r(p)
eststo tableS1_9

gen activechoice_highraven=activechoice*highraven
gen enhanced_highraven=enhancedactive*highraven
xi: reg eattend activechoice enhancedactive activechoice_highraven enhanced_highraven highraven i.market1, r


#delimit ;
esttab tableS1_* using tableS1.csv, replace depvar legend label nonumbers
	drop(_Imarket* _cons) 
	b(%9.3f) se star(* 0.10 ** 0.05 *** 0.01)
	stats(mean N pvalue, fmt(%9.3f %9.0g) labels("Opt-in Mean" "Sample Size" "p-value")) 
	title("Table S1: Heterogeneity of Impact of Treatment Type on Attendance") addnotes("""") ;
#delimit cr







